@@ -31,8 +31,6 @@
 #include "borrower.h"
 #include "datavectors.h"
 
-#include <ksharedptr.h>
-
 #include <QStringList>
 #include <QHash>
 #include <QObject>
@@ -332,16 +330,7 @@ public:
    */
   static const QString s_peopleGroupName;
 
-  enum DefaultField {
-    IDField,
-    TitleField,
-    CreatedDateField,
-    ModifiedDateField
-  };
-
-  static FieldPtr createDefaultField(DefaultField field);
-
-signals:
+Q_SIGNALS:
   void signalGroupsModified(Tellico::Data::CollPtr coll, QList<Tellico::Data::EntryGroup*> groups);
   void signalRefreshField(Tellico::Data::FieldPtr field);
   void mergeAddedField(Tellico::Data::CollPtr coll, Tellico::Data::FieldPtr field);
