@@ -27,11 +27,11 @@
 #include "collection.h"
 #include "field.h"
 #include "derivedvalue.h"
-#include "tellico_utils.h"
+#include "utils/string_utils.h"
 #include "utils/stringset.h"
 #include "tellico_debug.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include <QRegExp>
 
@@ -157,10 +157,10 @@ QString Entry::formattedField(Tellico::Data::FieldPtr field_, FieldFormat::Reque
       foreach(const QString& row, FieldFormat::splitTable(field(field_->name()))) {
         QStringList columns = FieldFormat::splitRow(row);
         QStringList newValues;
-        foreach(const QString& value, FieldFormat::splitValue(columns.at(0))) {
-          newValues << FieldFormat::format(value, field_->formatType(), FieldFormat::DefaultFormat);
-        }
         if(!columns.isEmpty()) {
+          foreach(const QString& value, FieldFormat::splitValue(columns.at(0))) {
+            newValues << FieldFormat::format(value, field_->formatType(), FieldFormat::DefaultFormat);
+          }
           columns.replace(0, newValues.join(FieldFormat::delimiterString()));
         }
         rows << columns.join(FieldFormat::columnDelimiterString());
@@ -298,13 +298,13 @@ QStringList Entry::groupNamesByFieldName(const QString& fieldName_) const {
     // we only take groups from the first column
     foreach(const QString& row, FieldFormat::splitTable(field(f))) {
       const QStringList columns = FieldFormat::splitRow(row);
-      const QStringList values = FieldFormat::splitValue(columns.at(0));
+      const QStringList values = columns.isEmpty() ? QStringList() : FieldFormat::splitValue(columns.at(0));
       foreach(const QString& value, values) {
         groups.add(FieldFormat::format(value, f->formatType(), FieldFormat::DefaultFormat));
       }
     }
   } else if(f->hasFlag(Field::AllowMultiple)) {
-    // use a string split instead of regexp split. since we've already enforced the space after the semi-comma
+    // use a string split instead of regexp split, since we've already enforced the space after the semi-comma
     groups.add(FieldFormat::splitValue(formattedField(f), FieldFormat::StringSplit));
   } else {
     groups.add(formattedField(f));
