@@ -124,7 +124,7 @@ void AnimeNfoFetcher::stop() {
 
   if(m_job) {
     m_job->kill();
-    m_job = 0;
+    m_job = nullptr;
   }
   m_started = false;
   emit signalDone(this);
@@ -134,7 +134,7 @@ void AnimeNfoFetcher::slotComplete(KJob*) {
 //  myDebug();
 
   if(m_job->error()) {
-    m_job->ui()->showErrorMessage();
+    m_job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -147,7 +147,7 @@ void AnimeNfoFetcher::slotComplete(KJob*) {
   }
 
   // since the fetch is done, don't worry about holding the job pointer
-  m_job = 0;
+  m_job = nullptr;
 
   QString s = Tellico::decodeHTML(data);
 #if 0
