@@ -25,19 +25,20 @@
 #include "arxivfetcher.h"
 #include "../translators/xslthandler.h"
 #include "../translators/tellicoimporter.h"
-#include "../gui/guiproxy.h"
-#include "../tellico_utils.h"
+#include "../utils/guiproxy.h"
+#include "../utils/string_utils.h"
+#include "../utils/datafileregistry.h"
 #include "../collection.h"
 #include "../entry.h"
 #include "../core/netaccess.h"
 #include "../images/imagefactory.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
-#include <kstandarddirs.h>
+#include <KLocalizedString>
+#include <KIO/Job>
+#include <KIO/JobUiDelegate>
 #include <KConfigGroup>
+#include <KJobWidgets/KJobWidgets>
 
 #include <QDomDocument>
 #include <QLabel>
@@ -45,8 +46,7 @@
 #include <QPixmap>
 #include <QVBoxLayout>
 #include <QFile>
-
-//#define ARXIV_TEST
+#include <QUrlQuery>
 
 namespace {
   static const int ARXIV_RETURNS_PER_REQUEST = 20;
@@ -58,12 +58,12 @@ using namespace Tellico::Fetch;
 using Tellico::Fetch::ArxivFetcher;
 
 ArxivFetcher::ArxivFetcher(QObject* parent_)
-    : Fetcher(parent_), m_xsltHandler(0), m_start(0), m_job(0), m_started(false) {
+    : Fetcher(parent_), m_xsltHandler(nullptr), m_start(0), m_total(-1), m_job(nullptr), m_started(false) {
 }
 
 ArxivFetcher::~ArxivFetcher() {
   delete m_xsltHandler;
-  m_xsltHandler = 0;
+  m_xsltHandler = nullptr;
 }
 
 QString ArxivFetcher::source() const {
@@ -90,14 +90,14 @@ void ArxivFetcher::continueSearch() {
 }
 
 void ArxivFetcher::doSearch() {
-  KUrl u = searchURL(request().key, request().value);
+  QUrl u = searchURL(request().key, request().value);
   if(u.isEmpty()) {
     stop();
     return;
   }
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->ui()->setWindow(GUI::Proxy::widget());
+  KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job, SIGNAL(result(KJob*)),
           SLOT(slotComplete(KJob*)));
 }
@@ -109,7 +109,7 @@ void ArxivFetcher::stop() {
 //  myDebug();
   if(m_job) {
     m_job->kill();
-    m_job = 0;
+    m_job = nullptr;
   }
   m_started = false;
   emit signalDone(this);
@@ -119,7 +119,7 @@ void ArxivFetcher::slotComplete(KJob*) {
 //  myDebug();
 
   if(m_job->error()) {
-    m_job->ui()->showErrorMessage();
+    m_job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -132,7 +132,7 @@ void ArxivFetcher::slotComplete(KJob*) {
   }
 
   // since the fetch is done, don't worry about holding the job pointer
-  m_job = 0;
+  m_job = nullptr;
 #if 0
   myWarning() << "Remove debug from arxivfetcher.cpp";
   QFile f(QLatin1String("/tmp/test.xml"));
@@ -167,7 +167,7 @@ void ArxivFetcher::slotComplete(KJob*) {
   }
 
   // assume result is always utf-8
-  QString str = m_xsltHandler->applyStylesheet(QString::fromUtf8(data, data.size()));
+  QString str = m_xsltHandler->applyStylesheet(QString::fromUtf8(data.constData(), data.size()));
   Import::TellicoImporter imp(str);
   Data::CollPtr coll = imp.collection();
 
@@ -205,7 +205,7 @@ Tellico::Data::EntryPtr ArxivFetcher::fetchEntryHook(uint uid_) {
       coll->addField(field);
     }
     if(entry->field(field).isEmpty()) {
-      QPixmap pix = NetAccess::filePreview(entry->field(QLatin1String("url")));
+      QPixmap pix = NetAccess::filePreview(QUrl::fromUserInput(entry->field(QLatin1String("url"))));
       if(!pix.isNull()) {
         QString id = ImageFactory::addImage(pix, QLatin1String("PNG"));
         if(!id.isEmpty()) {
@@ -225,29 +225,29 @@ Tellico::Data::EntryPtr ArxivFetcher::fetchEntryHook(uint uid_) {
 }
 
 void ArxivFetcher::initXSLTHandler() {
-  QString xsltfile = KStandardDirs::locate("appdata", QLatin1String("arxiv2tellico.xsl"));
+  QString xsltfile = DataFileRegistry::self()->locate(QLatin1String("arxiv2tellico.xsl"));
   if(xsltfile.isEmpty()) {
     myWarning() << "can not locate arxiv2tellico.xsl.";
     return;
   }
 
-  KUrl u;
-  u.setPath(xsltfile);
+  QUrl u = QUrl::fromLocalFile(xsltfile);
 
   delete m_xsltHandler;
   m_xsltHandler = new XSLTHandler(u);
   if(!m_xsltHandler->isValid()) {
     myWarning() << "error in arxiv2tellico.xsl.";
     delete m_xsltHandler;
-    m_xsltHandler = 0;
+    m_xsltHandler = nullptr;
     return;
   }
 }
 
-KUrl ArxivFetcher::searchURL(FetchKey key_, const QString& value_) const {
-  KUrl u(ARXIV_BASE_URL);
-  u.addQueryItem(QLatin1String("start"), QString::number(m_start));
-  u.addQueryItem(QLatin1String("max_results"), QString::number(ARXIV_RETURNS_PER_REQUEST));
+QUrl ArxivFetcher::searchURL(FetchKey key_, const QString& value_) const {
+  QUrl u(QString::fromLatin1(ARXIV_BASE_URL));
+  QUrlQuery q;
+  q.addQueryItem(QLatin1String("start"), QString::number(m_start));
+  q.addQueryItem(QLatin1String("max_results"), QString::number(ARXIV_RETURNS_PER_REQUEST));
 
   // quotes should be used if spaces are present
   QString value = value_;
@@ -282,13 +282,11 @@ KUrl ArxivFetcher::searchURL(FetchKey key_, const QString& value_) const {
 
     default:
       myWarning() << "key not recognized: " << request().key;
-      return KUrl();
+      return QUrl();
   }
-  u.addQueryItem(QLatin1String("search_query"), query);
+  q.addQueryItem(QLatin1String("search_query"), query);
+  u.setQuery(q);
 
-#ifdef ARXIV_TEST
-  u = KUrl::fromPathOrUrl("/home/robby/arxiv.xml");
-#endif
 //  myDebug() << "url: " << u;
   return u;
 }
@@ -336,5 +334,3 @@ void ArxivFetcher::ConfigWidget::saveConfigHook(KConfigGroup&) {
 QString ArxivFetcher::ConfigWidget::preferredName() const {
   return ArxivFetcher::defaultName();
 }
-
-#include "arxivfetcher.moc"
