@@ -153,7 +153,7 @@ QString BiblioShareFetcher::defaultName() {
 }
 
 QString BiblioShareFetcher::defaultIcon() {
-  return favIcon("http://www.biblioshare.org");
+  return favIcon("https://www.biblioshare.org");
 }
 
 BiblioShareFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const BiblioShareFetcher* fetcher_)
@@ -208,4 +208,3 @@ void BiblioShareFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
 QString BiblioShareFetcher::ConfigWidget::preferredName() const {
   return BiblioShareFetcher::defaultName();
 }
-
