@@ -22,33 +22,32 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h>
 #include "filmasterfetcher.h"
 #include "../collections/videocollection.h"
 #include "../images/imagefactory.h"
-#include "../gui/guiproxy.h"
-#include "../tellico_utils.h"
+#include "../utils/guiproxy.h"
+#include "../utils/string_utils.h"
 #include "../entry.h"
 #include "../core/filehandler.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
+#include <KLocalizedString>
+#include <KIO/Job>
+#include <KIO/JobUiDelegate>
+#include <KJobWidgets/KJobWidgets>
 
 #include <QLabel>
 #include <QFile>
 #include <QTextStream>
 #include <QGridLayout>
 #include <QTextCodec>
-
-#ifdef HAVE_QJSON
-#include <qjson/parser.h>
-#endif
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QUrlQuery>
 
 namespace {
   static const char* FILMASTER_API_URL = "http://api.filmaster.com";
-  static const char* FILMASTER_QUERY_URL = "http://api.filmaster.com/1.0/search/";
+  static const char* FILMASTER_QUERY_URL = "http://api.filmaster.com/1.1/search/";
 }
 
 using namespace Tellico;
@@ -71,11 +70,7 @@ QString FilmasterFetcher::attribution() const {
 }
 
 bool FilmasterFetcher::canSearch(FetchKey k) const {
-#ifndef HAVE_QJSON
-  return false;
-#else
   return k == Title || k == Person || k == Keyword;
-#endif
 }
 
 bool FilmasterFetcher::canFetch(int type) const {
@@ -88,31 +83,29 @@ void FilmasterFetcher::readConfigHook(const KConfigGroup&) {
 void FilmasterFetcher::search() {
   m_started = true;
 
-#ifdef HAVE_QJSON
-  KUrl u(FILMASTER_QUERY_URL);
+  QUrl u(QString::fromLatin1(FILMASTER_QUERY_URL));
 
   switch(request().key) {
     case Title:
-      u.addPath(QLatin1String("film/"));
+      u.setPath(u.path() + QLatin1String("film/"));
       break;
 
     case Person:
-      u.addPath(QLatin1String("person/"));
+      u.setPath(u.path() + QLatin1String("person/"));
       break;
 
     default:
       break;
   }
-  u.addQueryItem(QLatin1String("phrase"), request().value);
+  QUrlQuery q;
+  q.addQueryItem(QLatin1String("phrase"), request().value);
+  u.setQuery(q);
 
 //  myDebug() << "url:" << u;
 
   QPointer<KIO::StoredTransferJob> job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  job->ui()->setWindow(GUI::Proxy::widget());
+  KJobWidgets::setWindow(job, GUI::Proxy::widget());
   connect(job, SIGNAL(result(KJob*)), SLOT(slotComplete(KJob*)));
-#else
-  stop();
-#endif
 }
 
 void FilmasterFetcher::stop() {
@@ -121,7 +114,7 @@ void FilmasterFetcher::stop() {
   }
   if(m_job) {
     m_job->kill();
-    m_job = 0;
+    m_job = nullptr;
   }
   m_started = false;
   emit signalDone(this);
@@ -136,12 +129,20 @@ Tellico::Data::EntryPtr FilmasterFetcher::fetchEntryHook(uint uid_) {
 
   const QString image = entry->field(QLatin1String("cover"));
   if(image.contains(QLatin1Char('/'))) {
-    KUrl imageUrl(FILMASTER_API_URL);
-    imageUrl.addPath(image);
-    const QString id = ImageFactory::addImage(imageUrl, true);
-    if(!id.isEmpty()) {
-      entry->setField(QLatin1String("cover"), id);
+    QUrl imageUrl;
+    if(image.startsWith(QLatin1String("//"))) {
+      imageUrl = QUrl(QLatin1String("http:") + image);
+    } else {
+      imageUrl = QUrl(QString::fromLatin1(FILMASTER_API_URL));
+      imageUrl.setPath(imageUrl.path() + image);
     }
+    const QString id = ImageFactory::addImage(imageUrl, true);
+    if(id.isEmpty()) {
+      myDebug() << "Failed to load" << imageUrl;
+      message(i18n("The cover image could not be loaded."), MessageHandler::Warning);
+    }
+    // empty image ID is ok
+    entry->setField(QLatin1String("cover"), id);
   }
   return entry;
 }
@@ -155,14 +156,11 @@ Tellico::Fetch::FetchRequest FilmasterFetcher::updateRequest(Data::EntryPtr entr
 }
 
 void FilmasterFetcher::slotComplete(KJob* job_) {
-#ifndef HAVE_QJSON
-  stop();
-#else
   KIO::StoredTransferJob* job = static_cast<KIO::StoredTransferJob*>(job_);
 //  myDebug();
 
   if(job->error()) {
-    job->ui()->showErrorMessage();
+    job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -175,7 +173,7 @@ void FilmasterFetcher::slotComplete(KJob* job_) {
   }
   // see bug 319662. If fetcher is cancelled, job is killed
   // if the pointer is retained, it gets double-deleted
-  m_job = 0;
+  m_job = nullptr;
 
 #if 0
   myWarning() << "Remove debug from filmasterfetcher.cpp";
@@ -188,8 +186,8 @@ void FilmasterFetcher::slotComplete(KJob* job_) {
   f.close();
 #endif
 
-  QJson::Parser parser;
-  const QVariantMap resultsMap = parser.parse(data).toMap();
+  QJsonDocument doc = QJsonDocument::fromJson(data);
+  QVariantMap resultsMap = doc.object().toVariantMap();
   QVariantList resultList;
   switch(request().key) {
     case Title:
@@ -203,15 +201,15 @@ void FilmasterFetcher::slotComplete(KJob* job_) {
         QStringList uris;
         foreach(const QVariant& person, personList) {
           const QVariantMap personMap = person.toMap();
-          uris << value(personMap, "films_played_uri");
-          uris << value(personMap, "films_directed_uri");
+          uris << mapValue(personMap, "films_played_uri");
+          uris << mapValue(personMap, "films_directed_uri");
         }
         foreach(const QString& uri, uris) {
-          KUrl u(FILMASTER_API_URL);
+          QUrl u(QString::fromLatin1(FILMASTER_API_URL));
           u.setPath(uri);
-          // myDebug() << u;
           QString output = FileHandler::readTextFile(u, false /*quiet*/, true /*utf8*/);
-          resultList += parser.parse(output.toUtf8()).toMap().value(QLatin1String("objects")).toList();
+          QJsonDocument doc2 = QJsonDocument::fromJson(output.toUtf8());
+          resultList += doc2.object().toVariantMap().value(QLatin1String("objects")).toList();
         }
       }
       break;
@@ -251,41 +249,39 @@ void FilmasterFetcher::slotComplete(KJob* job_) {
 //  m_hasMoreResults = m_start <= m_total;
   m_hasMoreResults = false; // for now, no continued searches
   stop();
-#endif
 }
 
 void FilmasterFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap& result_) {
-#ifdef HAVE_QJSON
-  entry_->setField(QLatin1String("title"), value(result_, "title"));
-  entry_->setField(QLatin1String("year"), value(result_, "release_year"));
-  entry_->setField(QLatin1String("genre"), value(result_, "tags"));
-  entry_->setField(QLatin1String("nationality"), value(result_, "production_country_list"));
-  entry_->setField(QLatin1String("cover"), value(result_, "image"));
-  entry_->setField(QLatin1String("plot"), value(result_, "description"));
+  entry_->setField(QLatin1String("title"), mapValue(result_, "title"));
+  entry_->setField(QLatin1String("year"), mapValue(result_, "release_year"));
+  entry_->setField(QLatin1String("genre"), mapValue(result_, "tags"));
+  entry_->setField(QLatin1String("nationality"), mapValue(result_, "production_country_list"));
+  entry_->setField(QLatin1String("cover"), mapValue(result_, "image"));
+  entry_->setField(QLatin1String("plot"), mapValue(result_, "description"));
 
   QStringList directors;
   foreach(const QVariant& director, result_.value(QLatin1String("directors")).toList()) {
     const QVariantMap directorMap = director.toMap();
-    directors << value(directorMap, "name") + QLatin1Char(' ') + value(directorMap, "surname");
+    directors << mapValue(directorMap, "name") + QLatin1Char(' ') + mapValue(directorMap, "surname");
   }
   if(!directors.isEmpty()) {
     entry_->setField(QLatin1String("director"), directors.join(FieldFormat::delimiterString()));
   }
 
-  const QString castUri = value(result_, "characters_uri");
+  const QString castUri = mapValue(result_, "characters_uri");
   if(!castUri.isEmpty()) {
-    QJson::Parser parser;
-    KUrl u(FILMASTER_API_URL);
+    QUrl u(QString::fromLatin1(FILMASTER_API_URL));
     u.setPath(castUri);
     QString output = FileHandler::readTextFile(u, false /*quiet*/, true /*utf8*/);
-    const QVariantList castList = parser.parse(output.toUtf8()).toMap().value(QLatin1String("objects")).toList();
+    QJsonDocument doc = QJsonDocument::fromJson(output.toUtf8());
+    QVariantList castList = doc.object().toVariantMap().value(QLatin1String("objects")).toList();
     QStringList castLines;
     foreach(const QVariant& castResult, castList) {
       const QVariantMap castMap = castResult.toMap();
       const QVariantMap nameMap = castMap.value(QLatin1String("person")).toMap();
-      castLines << value(nameMap, "name") + QLatin1Char(' ') + value(nameMap, "surname")
+      castLines << mapValue(nameMap, "name") + QLatin1Char(' ') + mapValue(nameMap, "surname")
                  + FieldFormat::columnDelimiterString()
-                 + value(castMap, "character");
+                 + mapValue(castMap, "character");
     }
     if(!castLines.isEmpty()) {
       entry_->setField(QLatin1String("cast"), castLines.join(FieldFormat::rowDelimiterString()));
@@ -293,9 +289,8 @@ void FilmasterFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap& r
   }
 
   if(optionalFields().contains(QLatin1String("filmaster"))) {
-    entry_->setField(QLatin1String("filmaster"), QLatin1String("http://filmaster.com/film/") + value(result_, "permalink"));
+    entry_->setField(QLatin1String("filmaster"), QLatin1String("http://filmaster.com/film/") + mapValue(result_, "permalink"));
   }
-#endif
 }
 
 Tellico::Fetch::ConfigWidget* FilmasterFetcher::configWidget(QWidget* parent_) const {
@@ -332,20 +327,3 @@ void FilmasterFetcher::ConfigWidget::saveConfigHook(KConfigGroup&) {
 QString FilmasterFetcher::ConfigWidget::preferredName() const {
   return FilmasterFetcher::defaultName();
 }
-
-QString FilmasterFetcher::value(const QVariantMap& map, const char* name) {
-  const QVariant v = map.value(QLatin1String(name));
-  if(v.isNull())  {
-    return QString();
-  } else if(v.canConvert(QVariant::String)) {
-    return v.toString();
-  } else if(v.canConvert(QVariant::StringList)) {
-    return v.toStringList().join(Tellico::FieldFormat::delimiterString());
-  } else if(v.canConvert(QVariant::Map)) {
-    return v.toMap().value(QLatin1String("value")).toString();
-  } else {
-    return QString();
-  }
-}
-
-#include "filmasterfetcher.moc"
