@@ -23,29 +23,24 @@
  ***************************************************************************/
 
 #include "imdbfetcher.h"
-#include "../gui/guiproxy.h"
+#include "../utils/guiproxy.h"
 #include "../collections/videocollection.h"
 #include "../entry.h"
 #include "../field.h"
 #include "../fieldformat.h"
 #include "../core/filehandler.h"
 #include "../images/imagefactory.h"
-#include "../tellico_utils.h"
-#include "../gui/listwidgetitem.h"
-#include "../gui/combobox.h"
+#include "../utils/string_utils.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kdialog.h>
+#include <KLocalizedString>
 #include <KConfigGroup>
-#include <klineedit.h>
-#include <knuminput.h>
-#include <KVBox>
-#include <KListWidget>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
-#include <kacceleratormanager.h>
+#include <KIO/Job>
+#include <KJobUiDelegate>
+#include <KAcceleratorManager>
+#include <KJobWidgets/KJobWidgets>
 
+#include <QSpinBox>
 #include <QRegExp>
 #include <QFile>
 #include <QMap>
@@ -53,8 +48,7 @@
 #include <QCheckBox>
 #include <QGroupBox>
 #include <QGridLayout>
-
-//#define IMDB_TEST
+#include <QUrlQuery>
 
 namespace {
   static const uint IMDB_MAX_RESULTS = 20;
@@ -63,24 +57,24 @@ namespace {
 using namespace Tellico;
 using Tellico::Fetch::IMDBFetcher;
 
-QRegExp* IMDBFetcher::s_tagRx = 0;
-QRegExp* IMDBFetcher::s_anchorRx = 0;
-QRegExp* IMDBFetcher::s_anchorTitleRx = 0;
-QRegExp* IMDBFetcher::s_anchorNameRx = 0;
-QRegExp* IMDBFetcher::s_titleRx = 0;
+QRegExp* IMDBFetcher::s_tagRx = nullptr;
+QRegExp* IMDBFetcher::s_anchorRx = nullptr;
+QRegExp* IMDBFetcher::s_anchorTitleRx = nullptr;
+QRegExp* IMDBFetcher::s_anchorNameRx = nullptr;
+QRegExp* IMDBFetcher::s_titleRx = nullptr;
 
 // static
 void IMDBFetcher::initRegExps() {
   s_tagRx = new QRegExp(QLatin1String("<.*>"));
   s_tagRx->setMinimal(true);
 
-  s_anchorRx = new QRegExp(QLatin1String("<a\\s+[^>]*href\\s*=\\s*\"([^\"]*)\"[^<]*>([^<]*)</a>"), Qt::CaseInsensitive);
+  s_anchorRx = new QRegExp(QLatin1String("<a\\s+[^>]*href\\s*=\\s*\"([^\"]+)\"[^<]*>([^<]+)</a>"), Qt::CaseInsensitive);
   s_anchorRx->setMinimal(true);
 
   s_anchorTitleRx = new QRegExp(QLatin1String("<a\\s+[^>]*href\\s*=\\s*\"([^\"]*/title/[^\"]*)\"[^<]*>([^<]*)</a>"), Qt::CaseInsensitive);
   s_anchorTitleRx->setMinimal(true);
 
-  s_anchorNameRx = new QRegExp(QLatin1String("<a\\s+[^>]*href\\s*=\\s*\"([^\"]*/name/[^\"]*)\"[^<]*>([^<]*)</a>"), Qt::CaseInsensitive);
+  s_anchorNameRx = new QRegExp(QLatin1String("<a\\s+[^>]*href\\s*=\\s*\"([^\"]*/name/[^\"]*)\"[^<]*>(.+)</a>"), Qt::CaseInsensitive);
   s_anchorNameRx->setMinimal(true);
 
   s_titleRx = new QRegExp(QLatin1String("<title>(.*)</title>"), Qt::CaseInsensitive);
@@ -104,6 +98,7 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QLatin1String("aka"),
       QLatin1String("Director"),
       QLatin1String("Writer"),
+      QLatin1String("Produced by"),
       QLatin1String("runtime:.*(\\d+)\\s+min"),
       QLatin1String("aspect ratio:"),
       QLatin1String("also known as"),
@@ -131,6 +126,7 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QLatin1String("autre titre"),
       QString::fromUtf8("Réalisateur"),
       QString::fromUtf8("Scénarist"),
+      QString(),
       QString::fromUtf8("Durée:.*(\\d+)\\s+min"),
       QLatin1String("Format :"),
       QLatin1String("Alias"),
@@ -158,6 +154,7 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QString::fromUtf8("otro título"),
       QLatin1String("Director"),
       QLatin1String("Escritores"),
+      QString(),
       QString::fromUtf8("Duración:.*(\\d+)\\s+min"),
       QString::fromUtf8("Relación de Aspecto:"),
       QLatin1String("Conocido como"),
@@ -185,6 +182,7 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QString::fromUtf8("andere titel"),
       QLatin1String("Regisseur"),
       QLatin1String("Drehbuchautoren"),
+      QString(),
       QString::fromUtf8("Länge:.*(\\d+)\\s+min"),
       QString::fromUtf8("Seitenverhältnis:"),
       QLatin1String("Auch bekannt als"),
@@ -212,6 +210,7 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QString::fromUtf8("otro título"),
       QLatin1String("Regista"),
       QLatin1String("Sceneggiatori"),
+      QString(),
       QString::fromUtf8("Durata:.*(\\d+)\\s+min"),
       QString::fromUtf8("Aspect Ratio:"),
       QLatin1String("Alias"),
@@ -239,6 +238,7 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QString::fromUtf8("otro título"),
       QLatin1String("Diretor"),
       QLatin1String("Escritores"),
+      QString(),
       QString::fromUtf8("Duração:.*(\\d+)\\s+min"),
       QString::fromUtf8("Resolução:"),
       QString::fromUtf8("Também Conhecido Como"),
@@ -261,8 +261,9 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
 }
 
 IMDBFetcher::IMDBFetcher(QObject* parent_) : Fetcher(parent_),
-    m_job(0), m_started(false), m_fetchImages(true),
-    m_numCast(10), m_limit(IMDB_MAX_RESULTS), m_lang(EN), m_countOffset(0) {
+    m_job(nullptr), m_started(false), m_fetchImages(true),
+    m_numCast(10), m_redirected(false), m_limit(IMDB_MAX_RESULTS), m_lang(EN),
+    m_currentTitleBlock(Unknown), m_countOffset(0) {
   if(!s_tagRx) {
     initRegExps();
   }
@@ -280,14 +281,16 @@ bool IMDBFetcher::canFetch(int type) const {
   return type == Data::Collection::Video;
 }
 
-// imdb can search title, person in english
+// imdb can search title only
 bool IMDBFetcher::canSearch(FetchKey k) const {
-  return k == Title || (m_lang == EN && k == Person);
+  return k == Title;
 }
 
 void IMDBFetcher::readConfigHook(const KConfigGroup& config_) {
+  /*
   const int lang = config_.readEntry("Lang", int(EN));
   m_lang = static_cast<Lang>(lang);
+  */
   if(m_name.isEmpty()) {
     m_name = langData(m_lang).siteTitle;
   }
@@ -313,34 +316,23 @@ void IMDBFetcher::search() {
   m_currentTitleBlock = Unknown;
   m_countOffset = 0;
 
-#ifdef IMDB_TEST
-  if(request().key == Title) {
-    m_url = KUrl(QLatin1String("/home/robby/imdb-title.html"));
-    m_redirected = false;
-  } else {
-    m_url = KUrl(QLatin1String("/home/robby/imdb-name.html"));
-    m_redirected = true;
-  }
-#else
-  m_url = KUrl();
-  m_url.setProtocol(QLatin1String("http"));
+  m_url = QUrl();
+  m_url.setScheme(QLatin1String("http"));
   m_url.setHost(m_host);
   m_url.setPath(QLatin1String("/find"));
 
   // as far as I can tell, the url encoding should always be iso-8859-1?
-  m_url.addQueryItem(QLatin1String("q"), request().value);
+  QUrlQuery q;
+  q.addQueryItem(QLatin1String("q"), request().value);
 
   switch(request().key) {
     case Title:
-      m_url.addQueryItem(QLatin1String("s"), QLatin1String("tt"));
-      break;
-
-    case Person:
-      m_url.addQueryItem(QLatin1String("s"), QLatin1String("nm"));
+      q.addQueryItem(QLatin1String("s"), QLatin1String("tt"));
+      m_url.setQuery(q);
       break;
 
     case Raw:
-      m_url = request().value;
+      m_url = QUrl(request().value);
       break;
 
     default:
@@ -350,14 +342,13 @@ void IMDBFetcher::search() {
   }
 
 //  myDebug() << m_url;
-#endif
 
   m_job = KIO::storedGet(m_url, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->ui()->setWindow(GUI::Proxy::widget());
+  KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job, SIGNAL(result(KJob*)),
           SLOT(slotComplete(KJob*)));
-  connect(m_job, SIGNAL(redirection(KIO::Job*, const KUrl&)),
-          SLOT(slotRedirection(KIO::Job*, const KUrl&)));
+  connect(m_job, SIGNAL(redirection(KIO::Job*, const QUrl&)),
+          SLOT(slotRedirection(KIO::Job*, const QUrl&)));
 }
 
 void IMDBFetcher::continueSearch() {
@@ -386,10 +377,6 @@ void IMDBFetcher::continueSearch() {
     m_currentTitleBlock = m_countOffset == 0 ? Unknown : Approx;
   }
 
-  if(m_currentTitleBlock == SinglePerson) {
-    parseSingleNameResult();
-  }
-
   stop();
 }
 
@@ -400,7 +387,7 @@ void IMDBFetcher::stop() {
 //  myLog();
   if(m_job) {
     m_job->kill();
-    m_job = 0;
+    m_job = nullptr;
   }
 
   m_started = false;
@@ -409,7 +396,7 @@ void IMDBFetcher::stop() {
   emit signalDone(this);
 }
 
-void IMDBFetcher::slotRedirection(KIO::Job*, const KUrl& toURL_) {
+void IMDBFetcher::slotRedirection(KIO::Job*, const QUrl& toURL_) {
   m_url = toURL_;
   if(m_url.path().contains(QRegExp(QLatin1String("/tt\\d+/$"))))  {
     m_url.setPath(m_url.path() + QLatin1String("combined"));
@@ -419,7 +406,7 @@ void IMDBFetcher::slotRedirection(KIO::Job*, const KUrl& toURL_) {
 
 void IMDBFetcher::slotComplete(KJob*) {
   if(m_job->error()) {
-    m_job->ui()->showErrorMessage();
+    m_job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -430,6 +417,9 @@ void IMDBFetcher::slotComplete(KJob*) {
     stop();
     return;
   }
+  // see bug 319662. If fetcher is cancelled, job is killed
+  // if the pointer is retained, it gets double-deleted
+  m_job = nullptr;
 
 #if 0
   myWarning() << "Remove debug from imdbfetcher.cpp";
@@ -442,9 +432,6 @@ void IMDBFetcher::slotComplete(KJob*) {
   f.close();
 #endif
 
-  // since the fetch is done, don't worry about holding the job pointer
-  m_job = 0;
-
   // a single result was found if we got redirected
   switch(request().key) {
     case Title:
@@ -455,14 +442,6 @@ void IMDBFetcher::slotComplete(KJob*) {
       }
       break;
 
-    case Person:
-      if(m_redirected) {
-        parseSingleNameResult();
-      } else {
-        parseMultipleNameResults();
-      }
-      break;
-
     case Raw:
       parseSingleTitleResult();
       break;
@@ -484,9 +463,10 @@ void IMDBFetcher::parseSingleTitleResult() {
                                    pPos == -1 ? QString() : cap1.mid(pPos));
   // IMDB returns different HTML for single title results and has a query in the url
   // clear the query so we download the "canonical" page for the title
-  KUrl url(m_url);
-  url.setEncodedQuery(QByteArray());
+  QUrl url(m_url);
+  url.setQuery(QString());
   m_matches.insert(r->uid, url);
+  m_allMatches.insert(r->uid, url);
   emit signalResultFound(r);
 
   m_hasMoreResults = false;
@@ -628,9 +608,10 @@ void IMDBFetcher::parseTitleBlock(const QString& str_) {
     }
 
     FetchResult* r = new FetchResult(Fetcher::Ptr(this), pPos == -1 ? cap2 : cap2.left(pPos), desc);
-    KUrl u(m_url, cap1);
+    QUrl u = QUrl(m_url).resolved(QUrl(cap1));
     u.setQuery(QString());
     m_matches.insert(r->uid, u);
+    m_allMatches.insert(r->uid, u);
     emit signalResultFound(r);
     ++count;
   }
@@ -640,228 +621,6 @@ void IMDBFetcher::parseTitleBlock(const QString& str_) {
   m_countOffset = m_matches.size() < m_limit ? 0 : count;
 }
 
-void IMDBFetcher::parseSingleNameResult() {
-//  DEBUG_LINE
-
-  m_currentTitleBlock = SinglePerson;
-
-  QString output = Tellico::decodeHTML(m_text);
-
-  int pos = s_anchorTitleRx->indexIn(output);
-  if(pos == -1) {
-    stop();
-    return;
-  }
-
-  QRegExp tvRegExp(QLatin1String("TV\\sEpisode"), Qt::CaseInsensitive);
-
-  int len = 0;
-  int count = 0;
-  QString desc;
-  for( ; m_started && pos > -1; pos = s_anchorTitleRx->indexIn(output, pos+len)) {
-    desc.clear();
-    bool isEpisode = false;
-    len = s_anchorTitleRx->cap(0).length();
-    // split title at parenthesis
-    const QString cap2 = s_anchorTitleRx->cap(2).trimmed();
-    int pPos = cap2.indexOf(QLatin1Char('('));
-    if(pPos > -1) {
-      desc = cap2.mid(pPos);
-    } else {
-      // look until the next <a
-      int aPos = output.indexOf(QLatin1String("<a"), pos+len, Qt::CaseInsensitive);
-      if(aPos == -1) {
-        aPos = output.length();
-      }
-      QString tmp = output.mid(pos+len, aPos-pos-len);
-      if(tvRegExp.indexIn(tmp) > -1) {
-        isEpisode = true;
-      }
-      pPos = tmp.indexOf(QLatin1Char('('));
-      if(pPos > -1) {
-        int pNewLine = tmp.indexOf(QLatin1String("<br"));
-        if(pNewLine == -1 || pPos < pNewLine) {
-          int pEnd = tmp.indexOf(QLatin1Char(')'), pPos+1);
-          desc = tmp.mid(pPos+1, pEnd-pPos-1).remove(*s_tagRx);
-        }
-        // but need to indicate it wasn't found initially
-        pPos = -1;
-      }
-    }
-
-    if(count < m_countOffset) {
-      ++count;
-      continue;
-    }
-
-    ++count;
-    if(isEpisode) {
-      continue;
-    }
-
-    // if we got this far, then there is a valid result
-    if(m_matches.size() >= m_limit) {
-      m_hasMoreResults = true;
-      break;
-    }
-
-    // FIXME: maybe remove parentheses here?
-    FetchResult* r = new FetchResult(Fetcher::Ptr(this), pPos == -1 ? cap2 : cap2.left(pPos), desc, QString());
-    KUrl u(m_url, s_anchorTitleRx->cap(1)); // relative URL constructor
-    u.setQuery(QString());
-    m_matches.insert(r->uid, u);
-//    myDebug() << u;
-//    myDebug() << cap2;
-    emit signalResultFound(r);
-  }
-  if(pos == -1) {
-    m_hasMoreResults = false;
-  }
-  m_countOffset = count - 1;
-
-  stop();
-}
-
-void IMDBFetcher::parseMultipleNameResults() {
-//  DEBUG_LINE
-
-  const LangData& data = langData(m_lang);
-  // the exact results are in the first table after the "exact results" text
-  QString output = Tellico::decodeHTML(m_text);
-  int pos = output.indexOf(data.result_popular, 0, Qt::CaseInsensitive);
-  if(pos == -1) {
-    pos = output.indexOf(data.match_exact, 0, Qt::CaseInsensitive);
-  }
-
-  // find beginning of partial matches
-  int end = output.indexOf(data.result_other, qMax(pos, 0), Qt::CaseInsensitive);
-  if(end == -1) {
-    end = output.indexOf(data.match_partial, qMax(pos, 0), Qt::CaseInsensitive);
-    if(end == -1) {
-      end = output.indexOf(data.match_approx, qMax(pos, 0), Qt::CaseInsensitive);
-      if(end == -1) {
-        end = output.length();
-      }
-    }
-  }
-
-  QMap<QString, KUrl> map;
-  QHash<QString, int> nameMap;
-
-  QString s;
-  // if found exact matches
-  if(pos > -1) {
-    pos = s_anchorNameRx->indexIn(output, pos+13);
-    while(pos > -1 && pos < end && m_matches.size() < m_limit) {
-      KUrl u(m_url, s_anchorNameRx->cap(1));
-      s = s_anchorNameRx->cap(2).trimmed() + QLatin1Char(' ');
-      // if more than one exact, add parentheses
-      if(nameMap.contains(s) && nameMap[s] > 0) {
-        // fix the first one that didn't have a number
-        if(nameMap[s] == 1) {
-          KUrl u2 = map[s];
-          map.remove(s);
-          map.insert(s + QLatin1String("(1) "), u2);
-        }
-        nameMap.insert(s, nameMap[s] + 1);
-        // check for duplicate names
-        s += QString::fromLatin1("(%1) ").arg(nameMap[s]);
-      } else {
-        nameMap.insert(s, 1);
-      }
-      map.insert(s, u);
-      pos = s_anchorNameRx->indexIn(output, pos+s_anchorNameRx->cap(0).length());
-    }
-  }
-
-  // go ahead and search for partial matches
-  pos = s_anchorNameRx->indexIn(output, end);
-  while(pos > -1 && m_matches.size() < m_limit) {
-    KUrl u(m_url, s_anchorNameRx->cap(1)); // relative URL
-    s = s_anchorNameRx->cap(2).trimmed();
-    if(nameMap.contains(s) && nameMap[s] > 0) {
-    // fix the first one that didn't have a number
-      if(nameMap[s] == 1) {
-        KUrl u2 = map[s];
-        map.remove(s);
-        map.insert(s + QLatin1String(" (1)"), u2);
-      }
-      nameMap.insert(s, nameMap[s] + 1);
-      // check for duplicate names
-      s += QString::fromLatin1(" (%1)").arg(nameMap[s]);
-    } else {
-      nameMap.insert(s, 1);
-    }
-    map.insert(s, u);
-    pos = s_anchorNameRx->indexIn(output, pos+s_anchorNameRx->matchedLength());
-  }
-
-  if(map.count() == 0) {
-    myLog() << "no name matches found.";
-    stop();
-    return;
-  }
-
-  KDialog dlg(GUI::Proxy::widget());
-  dlg.setCaption(i18n("Select IMDb Result"));
-  dlg.setModal(false);
-  dlg.setButtons(KDialog::Ok|KDialog::Cancel);
-
-  KVBox* box = new KVBox(&dlg);
-  box->setSpacing(10);
-  (void) new QLabel(i18n("<qt>Your search returned multiple matches. Please select one below.</qt>"), box);
-
-  KListWidget* listWidget = new KListWidget(box);
-  listWidget->setMinimumWidth(400);
-  listWidget->setWrapping(true);
-
-  QMapIterator<QString, KUrl> i(map);
-  while(i.hasNext()) {
-    i.next();
-    const QString& value = i.key();
-    if(value.endsWith(QLatin1Char(' '))) {
-      GUI::ListWidgetItem* box = new GUI::ListWidgetItem(value, listWidget);
-      box->setColored(true);
-      listWidget->insertItem(0, box);
-    } else {
-      GUI::ListWidgetItem* box = new GUI::ListWidgetItem(value, listWidget);
-      listWidget->addItem(box);
-    }
-  }
-  listWidget->item(0)->setSelected(true);
-  listWidget->setWhatsThis(i18n("<qt>Select a search result.</qt>"));
-
-  dlg.setMainWidget(box);
-  if(dlg.exec() != QDialog::Accepted) {
-    stop();
-    return;
-  }
-
-  QListWidgetItem* cItem = listWidget->currentItem();
-  QString cText;
-  if(cItem) {
-    cText = cItem->text();
-  }
-  if(cText.isEmpty()) {
-    stop();
-    return;
-  }
-
-  m_url = map[cText];
-
-  // redirected is true since that's how I tell if an exact match has been found
-  m_redirected = true;
-  m_text.clear();
-  m_job = KIO::storedGet(m_url, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->ui()->setWindow(GUI::Proxy::widget());
-  connect(m_job, SIGNAL(result(KJob*)),
-          SLOT(slotComplete(KJob*)));
-  connect(m_job, SIGNAL(redirection(KIO::Job *, const KUrl&)),
-          SLOT(slotRedirection(KIO::Job*, const KUrl&)));
-
-  // do not stop() here
-}
-
 Tellico::Data::EntryPtr IMDBFetcher::fetchEntryHook(uint uid_) {
   // if we already grabbed this one, then just pull it out of the dict
   Data::EntryPtr entry = m_entries[uid_];
@@ -869,16 +628,17 @@ Tellico::Data::EntryPtr IMDBFetcher::fetchEntryHook(uint uid_) {
     return entry;
   }
 
-  if(!m_matches.contains(uid_)) {
+  if(!m_matches.contains(uid_) && !m_allMatches.contains(uid_)) {
     myLog() << "no url found";
     return Data::EntryPtr();
   }
-  KUrl url = m_matches[uid_];
+  QUrl url = m_matches.contains(uid_) ? m_matches[uid_]
+                                      : m_allMatches[uid_];
   if(url.path().contains(QRegExp(QLatin1String("/tt\\d+/$"))))  {
     url.setPath(url.path() + QLatin1String("combined"));
   }
 
-  KUrl origURL = m_url; // keep to switch back
+  QUrl origURL = m_url; // keep to switch back
   QString results;
   // if the url matches the current one, no need to redownload it
   if(url == m_url) {
@@ -886,10 +646,6 @@ Tellico::Data::EntryPtr IMDBFetcher::fetchEntryHook(uint uid_) {
     results = Tellico::decodeHTML(m_text);
   } else {
     // now it's sychronous
-#ifdef IMDB_TEST
-    KUrl u(QLatin1String("/home/robby/imdb-title-result.html"));
-    results = Tellico::fromHtmlData(FileHandler::readDataFile(u));
-#else
     // be quiet about failure
     results = Tellico::fromHtmlData(FileHandler::readDataFile(url, true));
     m_url = url; // needed for processing
@@ -903,7 +659,6 @@ Tellico::Data::EntryPtr IMDBFetcher::fetchEntryHook(uint uid_) {
   f.close();
 #endif
     results = Tellico::decodeHTML(results);
-#endif
   }
   if(results.isEmpty()) {
     myLog() << "no text results";
@@ -956,7 +711,7 @@ Tellico::Data::EntryPtr IMDBFetcher::parseEntry(const QString& str_) {
     // we want to strip the "/combined" from the url
     QString url = m_url.url();
     if(url.endsWith(QLatin1String("/combined"))) {
-      url = m_url.upUrl().url();
+      url = m_url.adjusted(QUrl::RemoveFilename).url();
     }
     entry->setField(imdb, url);
   }
@@ -1012,7 +767,7 @@ void IMDBFetcher::doAlsoKnownAs(const QString& str_, Tellico::Data::EntryPtr ent
 
   // match until next b tag
 //  QRegExp akaRx(QLatin1String("also known as(.*)<b(?:\\s.*)?>"));
-  QRegExp akaRx(QString::fromLatin1("%1(.*)<span[>\\s/]").arg(langData(m_lang).also_known_as), Qt::CaseInsensitive);
+  QRegExp akaRx(QString::fromLatin1("%1(.*)(<a|<span)[>\\s/]").arg(langData(m_lang).also_known_as), Qt::CaseInsensitive);
   akaRx.setMinimal(true);
 
   if(akaRx.indexIn(str_) > -1 && !akaRx.cap(1).isEmpty()) {
@@ -1058,11 +813,11 @@ void IMDBFetcher::doAlsoKnownAs(const QString& str_, Tellico::Data::EntryPtr ent
       entry_->setField(QLatin1String("alttitle"), values.join(FieldFormat::rowDelimiterString()));
     }
   } else {
-    myLog() << "'Also Known As' not found";
+//    myLog() << "'Also Known As' not found";
   }
 }
 
-void IMDBFetcher::doPlot(const QString& str_, Tellico::Data::EntryPtr entry_, const KUrl& baseURL_) {
+void IMDBFetcher::doPlot(const QString& str_, Tellico::Data::EntryPtr entry_, const QUrl& baseURL_) {
   // plot summaries provided by users are on a separate page
   // should those be preferred?
 
@@ -1091,7 +846,7 @@ void IMDBFetcher::doPlot(const QString& str_, Tellico::Data::EntryPtr entry_, co
   if(useUserSummary) {
     QRegExp idRx(QLatin1String("title/(tt\\d+)"));
     idRx.indexIn(baseURL_.path());
-    KUrl plotURL = baseURL_;
+    QUrl plotURL = baseURL_;
     plotURL.setPath(QLatin1String("/title/") + idRx.cap(1) + QLatin1String("/plotsummary"));
     // be quiet about failure
     QString plotPage = Tellico::fromHtmlData(FileHandler::readDataFile(plotURL, true));
@@ -1128,7 +883,7 @@ void IMDBFetcher::doStudio(const QString& str_, Tellico::Data::EntryPtr entry_)
 
   const int pos1 = str_.indexOf(productionRx);
   if(pos1 == -1) {
-    myDebug() << "No studio found";
+//    myLog() << "No studio found";
     return;
   }
 
@@ -1156,8 +911,8 @@ void IMDBFetcher::doPerson(const QString& str_, Tellico::Data::EntryPtr entry_,
   br2Rx.setMinimal(true);
   QRegExp divRx(QLatin1String("<div\\s[^>]*class\\s*=\\s*\"(?:info|txt-block)\"[^>]*>(.*)</div"), Qt::CaseInsensitive);
   divRx.setMinimal(true);
-  QString name = QLatin1String("/name/");
 
+  const QString name = QLatin1String("/name/");
   StringSet people;
   for(int pos = str_.indexOf(divRx); pos > -1; pos = str_.indexOf(divRx, pos+divRx.matchedLength())) {
     const QString infoBlock = divRx.cap(1);
@@ -1177,21 +932,18 @@ void IMDBFetcher::doPerson(const QString& str_, Tellico::Data::EntryPtr entry_,
   }
 }
 
-void IMDBFetcher::doCast(const QString& str_, Tellico::Data::EntryPtr entry_, const KUrl& baseURL_) {
+void IMDBFetcher::doCast(const QString& str_, Tellico::Data::EntryPtr entry_, const QUrl& baseURL_) {
   // the extended cast list is on a separate page
   // that's usually a lot of people
   // but since it can be in billing order, the main actors might not
   // be in the short list
   QRegExp idRx(QLatin1String("title/(tt\\d+)"));
   idRx.indexIn(baseURL_.path());
-#ifdef IMDB_TEST
-  KUrl castURL(QLatin1String("/home/robby/imdb-title-fullcredits.html"));
-#else
-  KUrl castURL = baseURL_;
+  QUrl castURL = baseURL_;
   castURL.setPath(QLatin1String("/title/") + idRx.cap(1) + QLatin1String("/fullcredits"));
-#endif
+
   // be quiet about failure and be sure to translate entities
-  QString castPage = Tellico::decodeHTML(FileHandler::readTextFile(castURL, true));
+  const QString castPage = Tellico::decodeHTML(FileHandler::readTextFile(castURL, true));
 #if 0
   myWarning() << "Remove debug from imdbfetcher.cpp";
   QFile f(QString::fromLatin1("/tmp/testimdbcast.html"));
@@ -1219,7 +971,7 @@ void IMDBFetcher::doCast(const QString& str_, Tellico::Data::EntryPtr entry_, co
     QRegExp castAnchorRx(QLatin1String("<a\\s+name\\s*=\\s*\"cast\""), Qt::CaseInsensitive);
     pos = castAnchorRx.indexIn(castText);
     if(pos < 0) {
-      QRegExp tableClassRx(QLatin1String("<table\\s+class\\s*=\\s*\"cast\""), Qt::CaseInsensitive);
+      QRegExp tableClassRx(QLatin1String("<table\\s+class\\s*=\\s*\"cast_list\""), Qt::CaseInsensitive);
       pos = tableClassRx.indexIn(castText);
       if(pos < 0) {
         // fragile, the word "cast" appears in the title, but need to find
@@ -1230,7 +982,7 @@ void IMDBFetcher::doCast(const QString& str_, Tellico::Data::EntryPtr entry_, co
         pos = castText.indexOf(castEnd, 0, Qt::CaseInsensitive);
         if(pos > 9) {
           // back up 9 places
-          if(castText.mid(pos-9, 9).startsWith(data.episodes)) {
+          if(castText.midRef(pos-9, 9).startsWith(data.episodes)) {
             // find next cast list
             pos = castText.indexOf(castEnd, pos+6, Qt::CaseInsensitive);
           }
@@ -1243,33 +995,72 @@ void IMDBFetcher::doCast(const QString& str_, Tellico::Data::EntryPtr entry_, co
     return;
   }
 
-  const QString name = QLatin1String("/name/");
   QRegExp tdRx(QLatin1String("<td[^>]*>(.*)</td>"), Qt::CaseInsensitive);
   tdRx.setMinimal(true);
 
+  QRegExp tdActorRx(QLatin1String("<td\\s+[^>]*itemprop=\"actor\"[^>]*>(.*)</td>"), Qt::CaseInsensitive);
+  tdActorRx.setMinimal(true);
+
+  QRegExp tdCharRx(QLatin1String("<td\\s+[^>]*class=\"character\"[^>]*>(.*)</td>"), Qt::CaseInsensitive);
+  tdCharRx.setMinimal(true);
+
   QStringList cast;
   // loop until closing table tag
-  const int endPos = castText.indexOf(QLatin1String("</table"), pos, Qt::CaseInsensitive);
-  pos = s_anchorRx->indexIn(castText, pos+1);
-  while(pos > -1 && pos < endPos && cast.count() < m_numCast) {
-    if(s_anchorRx->cap(1).contains(name)) {
-      // now search for <td> item with character name
-      // there's a column with ellipses then the character
-      const int pos2 = tdRx.indexIn(castText, pos);
-      if(pos2 > -1 && tdRx.indexIn(castText, pos2+tdRx.matchedLength()) > -1) {
-        cast += s_anchorRx->cap(2).trimmed()
-              + FieldFormat::columnDelimiterString()
-              + tdRx.cap(1).simplified().remove(*s_tagRx);
-      } else {
-        cast += s_anchorRx->cap(2).trimmed();
-      }
+  int endPos = castText.indexOf(QLatin1String("</table"), pos, Qt::CaseInsensitive);
+  castText = castText.mid(pos, endPos-pos+1);
+  pos = tdActorRx.indexIn(castText);
+  while(pos > -1 && cast.count() < m_numCast) {
+    QString actorText = tdActorRx.cap(1).remove(*s_tagRx).simplified();
+    const int pos2 = tdCharRx.indexIn(castText, pos+1);
+    if(pos2 > -1) {
+      cast += actorText
+            + FieldFormat::columnDelimiterString()
+            + tdCharRx.cap(1).remove(*s_tagRx).simplified();
     }
-    pos = s_anchorRx->indexIn(castText, pos+1);
+    pos = tdActorRx.indexIn(castText, qMax(pos+1, pos2));
   }
 
   if(!cast.isEmpty()) {
     entry_->setField(QLatin1String("cast"), cast.join(FieldFormat::rowDelimiterString()));
   }
+
+  // also do other items from fullcredits page, like producer
+  QStringList producers;
+  pos = castPage.indexOf(data.producer, 0, Qt::CaseInsensitive);
+  if(pos > -1) {
+    endPos = castText.indexOf(QLatin1String("</table"), pos, Qt::CaseInsensitive);
+    if(endPos == -1) {
+      endPos = castText.length();
+    }
+    const QString prodText = castPage.mid(pos, endPos-pos+1);
+    tdCharRx.setPattern(QLatin1String("<td\\s+[^>]*class=\"credit\"[^>]*>(.*)</td>"));
+
+    pos = s_anchorNameRx->indexIn(prodText);
+    while(pos > -1) {
+      const int pos2 = tdCharRx.indexIn(prodText, pos+1);
+      const QString credit = tdCharRx.cap(1).trimmed();
+      if(pos2 > -1 && (credit.startsWith(QLatin1String("producer")) ||
+                       credit.startsWith(QLatin1String("co-producer")) ||
+                       credit.startsWith(QLatin1String("associate producer")))) {
+        producers += s_anchorNameRx->cap(2).trimmed();
+      }
+      pos = s_anchorNameRx->indexIn(prodText, pos+1);
+    }
+  }
+
+  if(!producers.isEmpty()) {
+    entry_->setField(QLatin1String("producer"), producers.join(FieldFormat::delimiterString()));
+  }
+#if 0
+  myWarning() << "Remove debug from imdbfetcher.cpp";
+  QFile f2(QString::fromLatin1("/tmp/testimdbcast2.html"));
+  if(f2.open(QIODevice::WriteOnly)) {
+    QTextStream t(&f);
+    t.setCodec("UTF-8");
+    t << producers.join(FieldFormat::delimiterString());
+  }
+  f2.close();
+#endif
 }
 
 void IMDBFetcher::doRating(const QString& str_, Tellico::Data::EntryPtr entry_) {
@@ -1299,7 +1090,7 @@ void IMDBFetcher::doRating(const QString& str_, Tellico::Data::EntryPtr entry_)
   }
 }
 
-void IMDBFetcher::doCover(const QString& str_, Tellico::Data::EntryPtr entry_, const KUrl& baseURL_) {
+void IMDBFetcher::doCover(const QString& str_, Tellico::Data::EntryPtr entry_, const QUrl& baseURL_) {
   QRegExp imgRx(QLatin1String("<img\\s+[^>]*src\\s*=\\s*\"([^\"]*)\"[^>]*>"), Qt::CaseInsensitive);
   imgRx.setMinimal(true);
 
@@ -1311,7 +1102,7 @@ void IMDBFetcher::doCover(const QString& str_, Tellico::Data::EntryPtr entry_, c
   int pos = posterRx.indexIn(str_);
   while(pos > -1) {
     if(posterRx.cap(1).contains(imgRx)) {
-      KUrl u(baseURL_, imgRx.cap(1));
+      QUrl u = QUrl(baseURL_).resolved(QUrl(imgRx.cap(1)));
       QString id = ImageFactory::addImage(u, true);
       if(!id.isEmpty()) {
         entry_->setField(cover, id);
@@ -1328,7 +1119,7 @@ void IMDBFetcher::doCover(const QString& str_, Tellico::Data::EntryPtr entry_, c
   while(pos > -1) {
     const QString url = imgRx.cap(0).toLower();
     if(url.contains(cover)) {
-      KUrl u(baseURL_, imgRx.cap(1));
+      QUrl u = QUrl(baseURL_).resolved(QUrl(imgRx.cap(1)));
       QString id = ImageFactory::addImage(u, true);
       if(!id.isEmpty()) {
         entry_->setField(cover, id);
@@ -1351,7 +1142,7 @@ void IMDBFetcher::doCover(const QString& str_, Tellico::Data::EntryPtr entry_, c
       QRegExp hrefRx(QLatin1String("href=['\"](.*)['\"]"), Qt::CaseInsensitive);
       hrefRx.setMinimal(true);
       if(hrefRx.indexIn(tag) > -1) {
-        KUrl u(baseURL_, hrefRx.cap(1));
+        QUrl u = QUrl(baseURL_).resolved(QUrl(hrefRx.cap(1)));
         QString id = ImageFactory::addImage(u, true);
         if(!id.isEmpty()) {
           entry_->setField(cover, id);
@@ -1529,7 +1320,7 @@ void IMDBFetcher::doLists(const QString& str_, Tellico::Data::EntryPtr entry_) {
 
 Tellico::Fetch::FetchRequest IMDBFetcher::updateRequest(Data::EntryPtr entry_) {
   const QString t = entry_->field(QLatin1String("title"));
-  KUrl link = entry_->field(QLatin1String("imdb"));
+  QUrl link = QUrl::fromUserInput(entry_->field(QLatin1String("imdb")));
 
   if(!link.isEmpty() && link.isValid()) {
     if(link.host() != m_host) {
@@ -1551,7 +1342,7 @@ QString IMDBFetcher::defaultName() {
 }
 
 QString IMDBFetcher::defaultIcon() {
-  return favIcon("http://imdb.com");
+  return favIcon("http://www.imdb.com");
 }
 
 //static
@@ -1575,6 +1366,8 @@ IMDBFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const IMDBFetcher* fet
   l->setColumnStretch(1, 10);
 
   int row = -1;
+  /*
+  IMDB.fr and others now redirects to imdb.com
   QLabel* label = new QLabel(i18n("Country: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_langCombo = new GUI::ComboBox(optionsWidget());
@@ -1592,13 +1385,17 @@ IMDBFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const IMDBFetcher* fet
   label->setWhatsThis(w);
   m_langCombo->setWhatsThis(w);
   label->setBuddy(m_langCombo);
+  */
 
-  label = new QLabel(i18n("&Maximum cast: "), optionsWidget());
+  QLabel* label = new QLabel(i18n("&Maximum cast: "), optionsWidget());
   l->addWidget(label, ++row, 0);
-  m_numCast = new KIntSpinBox(0, 99, 1, 10, optionsWidget());
+  m_numCast = new QSpinBox(optionsWidget());
+  m_numCast->setMaximum(99);
+  m_numCast->setMinimum(0);
+  m_numCast->setValue(10);
   connect(m_numCast, SIGNAL(valueChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_numCast, row, 1);
-  w = i18n("The list of cast members may include many people. Set the maximum number returned from the search.");
+  QString w = i18n("The list of cast members may include many people. Set the maximum number returned from the search.");
   label->setWhatsThis(w);
   m_numCast->setWhatsThis(w);
   label->setBuddy(m_numCast);
@@ -1618,30 +1415,29 @@ IMDBFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const IMDBFetcher* fet
   KAcceleratorManager::manage(optionsWidget());
 
   if(fetcher_) {
-    m_langCombo->setCurrentData(fetcher_->m_lang);
+    // m_langCombo->setCurrentData(fetcher_->m_lang);
     m_numCast->setValue(fetcher_->m_numCast);
     m_fetchImageCheck->setChecked(fetcher_->m_fetchImages);
   } else { //defaults
-    m_langCombo->setCurrentData(EN);
+    // m_langCombo->setCurrentData(EN);
     m_numCast->setValue(10);
     m_fetchImageCheck->setChecked(true);
   }
 }
 
 void IMDBFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
-  int n = m_langCombo->currentData().toInt();
-  config_.writeEntry("Lang", n);
+  // int n = m_langCombo->currentData().toInt();
+  // config_.writeEntry("Lang", n);
   config_.writeEntry("Host", QString()); // clear old host entry
   config_.writeEntry("Max Cast", m_numCast->value());
   config_.writeEntry("Fetch Images", m_fetchImageCheck->isChecked());
 }
 
 QString IMDBFetcher::ConfigWidget::preferredName() const {
-  return IMDBFetcher::langData(m_langCombo->currentData().toInt()).siteTitle;
+  // return IMDBFetcher::langData(m_langCombo->currentData().toInt()).siteTitle;
+  return IMDBFetcher::langData(EN).siteTitle;
 }
 
 void IMDBFetcher::ConfigWidget::slotSiteChanged() {
   emit signalName(preferredName());
 }
-
-#include "imdbfetcher.moc"
