@@ -25,25 +25,28 @@
 #include "isbndbfetcher.h"
 #include "../translators/xslthandler.h"
 #include "../translators/tellicoimporter.h"
-#include "../gui/guiproxy.h"
-#include "../tellico_utils.h"
+#include "../utils/guiproxy.h"
+#include "../utils/string_utils.h"
 #include "../collection.h"
 #include "../entry.h"
+#include "../utils/datafileregistry.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
+#include <KLocalizedString>
+#include <KIO/Job>
+#include <KIO/JobUiDelegate>
 #include <KConfigGroup>
-#include <klineedit.h>
+#include <KJobWidgets/KJobWidgets>
 
+#include <QLineEdit>
 #include <QDomDocument>
+#include <QDomImplementation>
 #include <QLabel>
 #include <QFile>
 #include <QTextStream>
 #include <QVBoxLayout>
 #include <QTextCodec>
+#include <QUrlQuery>
 
 namespace {
   static const int ISBNDB_RETURNS_PER_REQUEST = 10;
@@ -56,14 +59,16 @@ using namespace Tellico;
 using Tellico::Fetch::ISBNdbFetcher;
 
 ISBNdbFetcher::ISBNdbFetcher(QObject* parent_)
-    : Fetcher(parent_), m_xsltHandler(0),
-      m_limit(ISBNDB_MAX_RETURNS_TOTAL), m_page(1), m_total(-1), m_countOffset(0),
-      m_job(0), m_started(false), m_apiKey(QLatin1String(ISBNDB_APP_ID)) {
+    : Fetcher(parent_), m_xsltHandler(nullptr),
+      m_limit(ISBNDB_MAX_RETURNS_TOTAL), m_page(1), m_total(-1), m_numResults(0), m_countOffset(0),
+      m_job(nullptr), m_started(false), m_apiKey(QLatin1String(ISBNDB_APP_ID)) {
+  // https://bugs.kde.org/show_bug.cgi?id=339063 -- some output is incorrectly encoded
+  QDomImplementation::setInvalidDataPolicy(QDomImplementation::DropInvalidChars);
 }
 
 ISBNdbFetcher::~ISBNdbFetcher() {
   delete m_xsltHandler;
-  m_xsltHandler = 0;
+  m_xsltHandler = nullptr;
 }
 
 QString ISBNdbFetcher::source() const {
@@ -100,34 +105,35 @@ void ISBNdbFetcher::continueSearch() {
 void ISBNdbFetcher::doSearch() {
 //  myDebug() << "value = " << value_;
 
-  KUrl u(ISBNDB_BASE_URL);
-  u.addPath(m_apiKey);
+  QUrl u(QString::fromLatin1(ISBNDB_BASE_URL));
+  u.setPath(u.path() + m_apiKey);
 
+  QUrlQuery q;
   switch(request().key) {
     case Title:
-      u.addPath(QLatin1String("books"));
-      u.addQueryItem(QLatin1String("q"), request().value);
+      u.setPath(u.path() + QLatin1String("books"));
+      q.addQueryItem(QLatin1String("q"), request().value);
       break;
 
     case Person:
-      u.addPath(QLatin1String("books"));
-      u.addQueryItem(QLatin1String("i"), QLatin1String("author_name"));
-      u.addQueryItem(QLatin1String("q"), request().value);
+      u.setPath(u.path() + QLatin1String("books"));
+      q.addQueryItem(QLatin1String("i"), QLatin1String("author_name"));
+      q.addQueryItem(QLatin1String("q"), request().value);
       break;
 
     case Keyword:
-      u.addPath(QLatin1String("books"));
-      u.addQueryItem(QLatin1String("i"), QLatin1String("full"));
-      u.addQueryItem(QLatin1String("q"), request().value);
+      u.setPath(u.path() + QLatin1String("books"));
+      q.addQueryItem(QLatin1String("i"), QLatin1String("full"));
+      q.addQueryItem(QLatin1String("q"), request().value);
       break;
 
     case ISBN:
-      u.addPath(QLatin1String("book"));
+      u.setPath(u.path() + QLatin1String("book"));
       {
         // can only grab first value
         QString v = request().value.section(QLatin1Char(';'), 0);
         v.remove(QLatin1Char('-'));
-        u.addPath(v);
+        u.setPath(u.path() + v);
       }
       break;
 
@@ -136,12 +142,13 @@ void ISBNdbFetcher::doSearch() {
       stop();
       return;
   }
-  u.addQueryItem(QLatin1String("page"), QString::number(m_page));
+  q.addQueryItem(QLatin1String("page"), QString::number(m_page));
+  u.setQuery(q);
 
   //  myDebug() << "url: " << u.url();
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->ui()->setWindow(GUI::Proxy::widget());
+  KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job, SIGNAL(result(KJob*)),
           SLOT(slotComplete(KJob*)));
 }
@@ -153,7 +160,7 @@ void ISBNdbFetcher::stop() {
 //  myDebug();
   if(m_job) {
     m_job->kill();
-    m_job = 0;
+    m_job = nullptr;
   }
 
   m_started = false;
@@ -164,7 +171,7 @@ void ISBNdbFetcher::slotComplete(KJob*) {
 //  myDebug();
 
   if(m_job->error()) {
-    m_job->ui()->showErrorMessage();
+    m_job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -177,7 +184,7 @@ void ISBNdbFetcher::slotComplete(KJob*) {
   }
 
   // since the fetch is done, don't worry about holding the job pointer
-  m_job = 0;
+  m_job = nullptr;
 #if 0
   myWarning() << "Remove debug from isbndbfetcher.cpp";
   QFile f(QLatin1String("/tmp/test.xml"));
@@ -192,6 +199,7 @@ void ISBNdbFetcher::slotComplete(KJob*) {
   QDomDocument dom;
   if(!dom.setContent(data, false)) {
     myWarning() << "server did not return valid XML.";
+    stop();
     return;
   }
 
@@ -212,11 +220,17 @@ void ISBNdbFetcher::slotComplete(KJob*) {
   }
 
   // assume result is always utf-8
-  QString str = m_xsltHandler->applyStylesheet(QString::fromUtf8(data, data.size()));
+  // https://bugs.kde.org/show_bug.cgi?id=339063 -- some output is incorrectly encoded
+//  QString str = m_xsltHandler->applyStylesheet(QString::fromUtf8(data.constData(), data.size()));
+  QString str = m_xsltHandler->applyStylesheet(dom.toString());
   Import::TellicoImporter imp(str);
   // be quiet when loading images
   imp.setOptions(imp.options() ^ Import::ImportShowImageErrors);
   Data::CollPtr coll = imp.collection();
+  if(!coll) {
+    stop();
+    return;
+  }
 
   if(coll->entryCount() == 0) {
     QDomNode n = dom.documentElement().namedItem(QLatin1String("ErrorMessage"));
@@ -292,21 +306,20 @@ Tellico::Data::EntryPtr ISBNdbFetcher::fetchEntryHook(uint uid_) {
 }
 
 void ISBNdbFetcher::initXSLTHandler() {
-  QString xsltfile = KStandardDirs::locate("appdata", QLatin1String("isbndb2tellico.xsl"));
+  QString xsltfile = DataFileRegistry::self()->locate(QLatin1String("isbndb2tellico.xsl"));
   if(xsltfile.isEmpty()) {
     myWarning() << "can not locate isbndb2tellico.xsl.";
     return;
   }
 
-  KUrl u;
-  u.setPath(xsltfile);
+  QUrl u = QUrl::fromLocalFile(xsltfile);
 
   delete m_xsltHandler;
   m_xsltHandler = new XSLTHandler(u);
   if(!m_xsltHandler->isValid()) {
     myWarning() << "error in isbndb2tellico.xsl.";
     delete m_xsltHandler;
-    m_xsltHandler = 0;
+    m_xsltHandler = nullptr;
     return;
   }
 }
@@ -356,7 +369,7 @@ ISBNdbFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const ISBNdbFetcher*
                                "If you agree to the terms and conditions, <a href='%2'>sign "
                                "up for an account</a>, and enter your information below.",
                                 preferredName(),
-                                QLatin1String("http://isbndb.com/docs/api/30-keys.html")),
+                                QLatin1String("http://isbndb.com/account/logincreate")),
                           optionsWidget());
   al->setOpenExternalLinks(true);
   al->setWordWrap(true);
@@ -368,7 +381,7 @@ ISBNdbFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const ISBNdbFetcher*
   QLabel* label = new QLabel(i18n("Access key: "), optionsWidget());
   l->addWidget(label, ++row, 0);
 
-  m_apiKeyEdit = new KLineEdit(optionsWidget());
+  m_apiKeyEdit = new QLineEdit(optionsWidget());
   connect(m_apiKeyEdit, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_apiKeyEdit, row, 1);
   QString w = i18n("The default Tellico key may be used, but searching may fail due to reaching access limits.");
@@ -400,5 +413,3 @@ void ISBNdbFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
 QString ISBNdbFetcher::ConfigWidget::preferredName() const {
   return ISBNdbFetcher::defaultName();
 }
-
-#include "isbndbfetcher.moc"
