@@ -48,27 +48,27 @@ class ISBNdbFetcher : public Fetcher {
 Q_OBJECT
 
 public:
-  ISBNdbFetcher(QObject* parent = 0);
+  ISBNdbFetcher(QObject* parent = nullptr);
   ~ISBNdbFetcher();
 
-  virtual QString source() const;
-  virtual bool isSearching() const { return m_started; }
-  virtual void continueSearch();
-  virtual bool canSearch(FetchKey k) const { return k == Title || k == Person || k == Keyword || k == ISBN; }
-  virtual void stop();
-  virtual Data::EntryPtr fetchEntryHook(uint uid);
-  virtual Type type() const { return ISBNdb; }
-  virtual bool canFetch(int type) const;
-  virtual void readConfigHook(const KConfigGroup& config);
+  virtual QString source() const Q_DECL_OVERRIDE;
+  virtual bool isSearching() const Q_DECL_OVERRIDE { return m_started; }
+  virtual void continueSearch() Q_DECL_OVERRIDE;
+  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE { return k == Title || k == Person || k == Keyword || k == ISBN; }
+  virtual void stop() Q_DECL_OVERRIDE;
+  virtual Data::EntryPtr fetchEntryHook(uint uid) Q_DECL_OVERRIDE;
+  virtual Type type() const Q_DECL_OVERRIDE { return ISBNdb; }
+  virtual bool canFetch(int type) const Q_DECL_OVERRIDE;
+  virtual void readConfigHook(const KConfigGroup& config) Q_DECL_OVERRIDE;
 
-  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const;
+  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const Q_DECL_OVERRIDE;
   void setLimit(int limit_) { m_limit = limit_; }
 
   class ConfigWidget : public Fetch::ConfigWidget {
   public:
-    explicit ConfigWidget(QWidget* parent_, const ISBNdbFetcher* fetcher = 0);
-    virtual void saveConfigHook(KConfigGroup&);
-    virtual QString preferredName() const;
+    explicit ConfigWidget(QWidget* parent_, const ISBNdbFetcher* fetcher = nullptr);
+    virtual void saveConfigHook(KConfigGroup&) Q_DECL_OVERRIDE;
+    virtual QString preferredName() const Q_DECL_OVERRIDE;
   private:
     QLineEdit* m_apiKeyEdit;
   };
@@ -82,8 +82,8 @@ private Q_SLOTS:
   void slotComplete(KJob* job);
 
 private:
-  virtual void search();
-  virtual FetchRequest updateRequest(Data::EntryPtr entry);
+  virtual void search() Q_DECL_OVERRIDE;
+  virtual FetchRequest updateRequest(Data::EntryPtr entry) Q_DECL_OVERRIDE;
   void initXSLTHandler();
   void doSearch();
 
