@@ -29,26 +29,29 @@
 #include "../translators/xslthandler.h"
 #include "../translators/tellicoimporter.h"
 #include "../translators/xmlimporter.h"
-#include "../gui/guiproxy.h"
+#include "../utils/guiproxy.h"
 #include "../gui/lineedit.h"
 #include "../gui/combobox.h"
-#include "../tellico_utils.h"
+#include "../gui/stringmapwidget.h"
+#include "../utils/string_utils.h"
 #include "../utils/lccnvalidator.h"
 #include "../utils/isbnvalidator.h"
+#include "../utils/datafileregistry.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
-#include <kstandarddirs.h>
+#include <KLocalizedString>
+#include <KIO/Job>
+#include <KJobUiDelegate>
+#include <KJobWidgets/KJobWidgets>
 #include <KConfigGroup>
-#include <kcombobox.h>
-#include <kacceleratormanager.h>
-#include <knuminput.h>
+#include <KComboBox>
+#include <KAcceleratorManager>
 
+#include <QSpinBox>
 #include <QLabel>
 #include <QGridLayout>
 #include <QFile>
+#include <QUrlQuery>
 
 namespace {
   // 7090 was the old default port, but that was just because LoC used it
@@ -61,23 +64,26 @@ using namespace Tellico;
 using Tellico::Fetch::SRUFetcher;
 
 SRUFetcher::SRUFetcher(QObject* parent_)
-    : Fetcher(parent_), m_job(0), m_MARCXMLHandler(0), m_MODSHandler(0), m_SRWHandler(0), m_started(false) {
+    : Fetcher(parent_), m_port(SRU_DEFAULT_PORT), m_job(nullptr), m_MARCXMLHandler(nullptr), m_MODSHandler(nullptr), m_SRWHandler(nullptr), m_started(false) {
 }
 
 SRUFetcher::SRUFetcher(const QString& name_, const QString& host_, uint port_, const QString& path_,
-                       QObject* parent_) : Fetcher(parent_),
-      m_host(host_), m_port(port_), m_path(path_), m_format(QLatin1String("mods")),
-      m_job(0), m_MARCXMLHandler(0), m_MODSHandler(0), m_SRWHandler(0), m_started(false) {
+                       const QString& format_, QObject* parent_) : Fetcher(parent_),
+      m_host(host_), m_port(port_), m_path(path_), m_format(format_),
+      m_job(nullptr), m_MARCXMLHandler(nullptr), m_MODSHandler(nullptr), m_SRWHandler(nullptr), m_started(false) {
   m_name = name_; // m_name is protected in super class
+  if(!m_path.startsWith(QLatin1Char('/'))) {
+    m_path.prepend(QLatin1Char('/'));
+  }
 }
 
 SRUFetcher::~SRUFetcher() {
   delete m_MARCXMLHandler;
-  m_MARCXMLHandler = 0;
+  m_MARCXMLHandler = nullptr;
   delete m_MODSHandler;
-  m_MODSHandler = 0;
+  m_MODSHandler = nullptr;
   delete m_SRWHandler;
-  m_SRWHandler = 0;
+  m_SRWHandler = nullptr;
 }
 
 QString SRUFetcher::source() const {
@@ -103,6 +109,12 @@ void SRUFetcher::readConfigHook(const KConfigGroup& config_) {
     m_path.prepend(QLatin1Char('/'));
   }
   m_format = config_.readEntry("Format", "mods");
+  const QStringList queryFields = config_.readEntry("QueryFields", QStringList());
+  const QStringList queryValues = config_.readEntry("QueryValues", QStringList());
+  Q_ASSERT(queryFields.count() == queryValues.count());
+  for(int i = 0; i < qMin(queryFields.count(), queryValues.count()); ++i) {
+    m_queryMap.insert(queryFields.at(i), queryValues.at(i));
+  }
 }
 
 void SRUFetcher::search() {
@@ -114,28 +126,36 @@ void SRUFetcher::search() {
 
   m_started = true;
 
-  KUrl u;
-  u.setProtocol(QLatin1String("http"));
+  QUrl u;
+  u.setScheme(QLatin1String("http"));
   u.setHost(m_host);
   u.setPort(m_port);
-  u.setPath(m_path);
+  u = QUrl::fromUserInput(u.url() + m_path);
 
-  u.addQueryItem(QLatin1String("operation"), QLatin1String("searchRetrieve"));
-  u.addQueryItem(QLatin1String("version"), QLatin1String("1.1"));
-  u.addQueryItem(QLatin1String("maximumRecords"), QString::number(SRU_MAX_RECORDS));
-  if(!m_format.isEmpty() && m_format != QLatin1String("none")) {
-    u.addQueryItem(QLatin1String("recordSchema"), m_format);
+  QUrlQuery query;
+  for(StringMap::ConstIterator it = m_queryMap.constBegin(); it != m_queryMap.constEnd(); ++it) {
+    query.addQueryItem(it.key(), it.value());
   }
-  // added for the nature.com openSearch, what's the best way to make this an option?
-  if(m_host.endsWith(QLatin1String("nature.com"))) {
-    u.addQueryItem(QLatin1String("httpAccept"), QLatin1String("application/sru+xml"));
+  // allow user to override these so check for existing item first
+  if(!query.hasQueryItem(QLatin1String("operation"))) {
+    query.addQueryItem(QLatin1String("operation"), QLatin1String("searchRetrieve"));
+  }
+  if(!query.hasQueryItem(QLatin1String("version"))) {
+    query.addQueryItem(QLatin1String("version"), QLatin1String("1.1"));
+  }
+  if(!query.hasQueryItem(QLatin1String("maximumRecords"))) {
+    query.addQueryItem(QLatin1String("maximumRecords"), QString::number(SRU_MAX_RECORDS));
+  }
+  if(!m_format.isEmpty() && m_format != QLatin1String("none")
+     && !query.hasQueryItem(QLatin1String("recordSchema"))) {
+    query.addQueryItem(QLatin1String("recordSchema"), m_format);
   }
 
   const int type = collectionType();
   QString str = QLatin1Char('"') + request().value + QLatin1Char('"');
   switch(request().key) {
     case Title:
-      u.addQueryItem(QLatin1String("query"), QLatin1String("dc.title=") + str);
+      query.addQueryItem(QLatin1String("query"), QLatin1String("dc.title=") + str);
       break;
 
     case Person:
@@ -146,7 +166,7 @@ void SRUFetcher::search() {
         } else {
           s = QLatin1String("dc.creator=") + str + QLatin1String(" or dc.editor=") + str;
         }
-        u.addQueryItem(QLatin1String("query"), s);
+        query.addQueryItem(QLatin1String("query"), s);
       }
       break;
 
@@ -166,12 +186,18 @@ void SRUFetcher::search() {
         }
         QString q;
         for(int i = 0; i < isbnList.count(); ++i) {
-          q += QLatin1String("bath.isbn=") + isbnList.at(i);
+          // make an assumption that DC output uses the dc profile and everything else uses Bath for ISBN
+          // no idea if this holds true universally, but matches LOC, COPAC, and KB
+          if(m_format == QLatin1String("dc")) {
+            q += QLatin1String("dc.identifier=") + isbnList.at(i);
+          } else {
+            q += QLatin1String("bath.isbn=") + isbnList.at(i);
+          }
           if(i < isbnList.count()-1) {
             q += QLatin1String(" or ");
           }
         }
-        u.addQueryItem(QLatin1String("query"), q);
+        query.addQueryItem(QLatin1String("query"), q);
       }
       break;
 
@@ -187,19 +213,19 @@ void SRUFetcher::search() {
             q += QLatin1String(" or ");
           }
         }
-        u.addQueryItem(QLatin1String("query"), q);
+        query.addQueryItem(QLatin1String("query"), q);
       }
       break;
 
     case Keyword:
-      u.addQueryItem(QLatin1String("query"), str);
+      query.addQueryItem(QLatin1String("query"), str);
       break;
 
     case Raw:
       {
         QString key = request().value.section(QLatin1Char('='), 0, 0).trimmed();
         QString str = request().value.section(QLatin1Char('='), 1).trimmed();
-        u.addQueryItem(key, str);
+        query.addQueryItem(key, str);
       }
       break;
 
@@ -208,10 +234,11 @@ void SRUFetcher::search() {
       stop();
       break;
   }
+  u.setQuery(query);
 //  myDebug() << u.url();
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->ui()->setWindow(GUI::Proxy::widget());
+  KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job, SIGNAL(result(KJob*)),
           SLOT(slotComplete(KJob*)));
 }
@@ -222,7 +249,7 @@ void SRUFetcher::stop() {
   }
   if(m_job) {
     m_job->kill();
-    m_job = 0;
+    m_job = nullptr;
   }
 
   m_started = false;
@@ -231,7 +258,7 @@ void SRUFetcher::stop() {
 
 void SRUFetcher::slotComplete(KJob*) {
   if(m_job->error()) {
-    m_job->ui()->showErrorMessage();
+    m_job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -243,7 +270,7 @@ void SRUFetcher::slotComplete(KJob*) {
   }
   // see bug 319662. If fetcher is cancelled, job is killed
   // if the pointer is retained, it gets double-deleted
-  m_job = 0;
+  m_job = nullptr;
 
 #if 0
   myWarning() << "Remove debug from srufetcher.cpp";
@@ -259,7 +286,7 @@ void SRUFetcher::slotComplete(KJob*) {
   Data::CollPtr coll;
   QString msg;
 
-  const QString result = QString::fromUtf8(data, data.size());
+  const QString result = QString::fromUtf8(data.constData(), data.size());
 
   // first check for SRU errors
   const QString& diag = XML::nsZingDiag;
@@ -290,8 +317,16 @@ void SRUFetcher::slotComplete(KJob*) {
   QString modsResult;
   if(m_format == QLatin1String("mods")) {
     modsResult = result;
-  } else if(m_format == QLatin1String("marcxml") && initMARCXMLHandler()) {
-    modsResult = m_MARCXMLHandler->applyStylesheet(result);
+//  } else if(m_format == QLatin1String("marcxml") && initMARCXMLHandler()) {
+// some SRU data sources call it MARC21-xml or something other than marcxml
+  } else if(m_format.startsWith(QLatin1String("marc"), Qt::CaseInsensitive) && initMARCXMLHandler()) {
+    // brute force marcxchange conversion. This is probably wrong at some level
+    QString newResult = result;
+    if(m_format.startsWith(QLatin1String("marcxchange"), Qt::CaseInsensitive)) {
+      newResult.replace(QRegExp(QLatin1String("xmlns:marc=\"info:lc/xmlns/marcxchange-v[12]\"")),
+                        QLatin1String("xmlns:marc=\"http://www.loc.gov/MARC21/slim\""));
+    }
+    modsResult = m_MARCXMLHandler->applyStylesheet(newResult);
   }
   if(!modsResult.isEmpty() && initMODSHandler()) {
     Import::TellicoImporter imp(m_MODSHandler->applyStylesheet(modsResult));
@@ -379,20 +414,19 @@ bool SRUFetcher::initMARCXMLHandler() {
     return true;
   }
 
-  QString xsltfile = KStandardDirs::locate("appdata", QLatin1String("MARC21slim2MODS3.xsl"));
+  QString xsltfile = DataFileRegistry::self()->locate(QLatin1String("MARC21slim2MODS3.xsl"));
   if(xsltfile.isEmpty()) {
     myWarning() << "can not locate MARC21slim2MODS3.xsl.";
     return false;
   }
 
-  KUrl u;
-  u.setPath(xsltfile);
+  QUrl u = QUrl::fromLocalFile(xsltfile);
 
   m_MARCXMLHandler = new XSLTHandler(u);
   if(!m_MARCXMLHandler->isValid()) {
     myWarning() << "error in MARC21slim2MODS3.xsl.";
     delete m_MARCXMLHandler;
-    m_MARCXMLHandler = 0;
+    m_MARCXMLHandler = nullptr;
     return false;
   }
   return true;
@@ -403,20 +437,19 @@ bool SRUFetcher::initMODSHandler() {
     return true;
   }
 
-  QString xsltfile = KStandardDirs::locate("appdata", QLatin1String("mods2tellico.xsl"));
+  QString xsltfile = DataFileRegistry::self()->locate(QLatin1String("mods2tellico.xsl"));
   if(xsltfile.isEmpty()) {
     myWarning() << "can not locate mods2tellico.xsl.";
     return false;
   }
 
-  KUrl u;
-  u.setPath(xsltfile);
+  QUrl u = QUrl::fromLocalFile(xsltfile);
 
   m_MODSHandler = new XSLTHandler(u);
   if(!m_MODSHandler->isValid()) {
     myWarning() << "error in mods2tellico.xsl.";
     delete m_MODSHandler;
-    m_MODSHandler = 0;
+    m_MODSHandler = nullptr;
     return false;
   }
   return true;
@@ -427,20 +460,19 @@ bool SRUFetcher::initSRWHandler() {
     return true;
   }
 
-  QString xsltfile = KStandardDirs::locate("appdata", QLatin1String("srw2tellico.xsl"));
+  QString xsltfile = DataFileRegistry::self()->locate(QLatin1String("srw2tellico.xsl"));
   if(xsltfile.isEmpty()) {
     myWarning() << "can not locate srw2tellico.xsl.";
     return false;
   }
 
-  KUrl u;
-  u.setPath(xsltfile);
+  QUrl u = QUrl::fromLocalFile(xsltfile);
 
   m_SRWHandler = new XSLTHandler(u);
   if(!m_SRWHandler->isValid()) {
     myWarning() << "error in srw2tellico.xsl.";
     delete m_SRWHandler;
-    m_SRWHandler = 0;
+    m_SRWHandler = nullptr;
     return false;
   }
   return true;
@@ -448,7 +480,7 @@ bool SRUFetcher::initSRWHandler() {
 
 Tellico::Fetch::Fetcher::Ptr SRUFetcher::libraryOfCongress(QObject* parent_) {
   return Fetcher::Ptr(new SRUFetcher(i18n("Library of Congress (US)"), QLatin1String("z3950.loc.gov"), 7090,
-                                     QLatin1String("voyager"), parent_));
+                                     QLatin1String("voyager"), QLatin1String("mods"), parent_));
 }
 
 QString SRUFetcher::defaultName() {
@@ -456,7 +488,8 @@ QString SRUFetcher::defaultName() {
 }
 
 QString SRUFetcher::defaultIcon() {
-  return QLatin1String("network-workgroup"); // just to be different than z3950
+//  return QLatin1String("network-workgroup"); // just to be different than z3950
+  return QLatin1String(":/icons/sru");
 }
 
 // static
@@ -494,7 +527,10 @@ SRUFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const SRUFetcher* fetch
 
   label = new QLabel(i18n("&Port: "), optionsWidget());
   l->addWidget(label, ++row, 0);
-  m_portSpinBox = new KIntSpinBox(0, 999999, 1, SRU_DEFAULT_PORT, optionsWidget());
+  m_portSpinBox = new QSpinBox(optionsWidget());
+  m_portSpinBox->setMaximum(999999);
+  m_portSpinBox->setMinimum(0);
+  m_portSpinBox->setValue(SRU_DEFAULT_PORT);
   connect(m_portSpinBox, SIGNAL(valueChanged(int)), SLOT(slotSetModified()));
   l->addWidget(m_portSpinBox, row, 1);
   w = i18n("Enter the port number of the server. The default is %1.", SRU_DEFAULT_PORT);
@@ -519,8 +555,9 @@ SRUFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const SRUFetcher* fetch
   m_formatCombo->addItem(QLatin1String("MARCXML"), QLatin1String("marcxml"));
   m_formatCombo->addItem(QLatin1String("PAM"), QLatin1String("pam"));
   m_formatCombo->addItem(QLatin1String("Dublin Core"), QLatin1String("dc"));
-  m_formatCombo->addItem(QLatin1String(""), QLatin1String("none"));
+  m_formatCombo->setEditable(true);
   connect(m_formatCombo, SIGNAL(activated(int)), SLOT(slotSetModified()));
+  connect(m_formatCombo, SIGNAL(editTextChanged(QString)), SLOT(slotSetModified()));
   l->addWidget(m_formatCombo, row, 1);
   w = i18n("Enter the result format used by the server.");
   label->setWhatsThis(w);
@@ -529,6 +566,10 @@ SRUFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const SRUFetcher* fetch
 
   l->setRowStretch(++row, 1);
 
+  m_queryTree = new GUI::StringMapWidget(StringMap(), optionsWidget());
+  l->addWidget(m_queryTree, row, 0, 1, 2);
+  m_queryTree->setLabels(i18n("Field"), i18n("Value"));
+
   // now add additional fields widget
   addFieldsWidget(SRUFetcher::allOptionalFields(), fetcher_ ? fetcher_->optionalFields() : QStringList());
 
@@ -536,7 +577,11 @@ SRUFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const SRUFetcher* fetch
     m_hostEdit->setText(fetcher_->m_host);
     m_portSpinBox->setValue(fetcher_->m_port);
     m_pathEdit->setText(fetcher_->m_path);
+    if(m_formatCombo->findData(fetcher_->m_format) == -1) {
+      m_formatCombo->addItem(fetcher_->m_format, fetcher_->m_format);
+    }
     m_formatCombo->setCurrentData(fetcher_->m_format);
+    m_queryTree->setStringMap(fetcher_->m_queryMap);
   }
   KAcceleratorManager::manage(optionsWidget());
 }
@@ -554,10 +599,19 @@ void SRUFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
   if(!s.isEmpty()) {
     config_.writeEntry("Path", s);
   }
-  s = m_formatCombo->currentData().toString();
+  s = m_formatCombo->currentData().toString().trimmed();
+  if(s.isEmpty()) {
+    // user-entered format will not have data set for the item. Just use the text itself
+    s = m_formatCombo->currentText().trimmed();
+  }
   if(!s.isEmpty()) {
     config_.writeEntry("Format", s);
   }
+  StringMap queryMap = m_queryTree->stringMap();
+  if(!queryMap.isEmpty()) {
+    config_.writeEntry("QueryFields", queryMap.keys());
+    config_.writeEntry("QueryValues", queryMap.values());
+  }
 }
 
 QString SRUFetcher::ConfigWidget::preferredName() const {
@@ -569,17 +623,15 @@ void SRUFetcher::ConfigWidget::slotCheckHost() {
   QString s = m_hostEdit->text();
   // someone might be pasting a full URL, check that
   if(s.indexOf(QLatin1Char(':')) > -1 || s.indexOf(QLatin1Char('/')) > -1) {
-    KUrl u(s);
+    QUrl u(s);
     if(u.isValid()) {
       m_hostEdit->setText(u.host());
       if(u.port() > 0) {
         m_portSpinBox->setValue(u.port());
       }
       if(!u.path().isEmpty()) {
-        m_pathEdit->setText(u.path());
+        m_pathEdit->setText(u.path().trimmed());
       }
     }
   }
 }
-
-#include "srufetcher.moc"
