@@ -27,15 +27,15 @@
 #include "z3950connection.h"
 #include "z3950fetcher.h"
 #include "messagehandler.h"
-#include "../tellico_debug.h"
 #include "../utils/iso5426converter.h"
 #include "../utils/iso6937converter.h"
+#include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kapplication.h>
+#include <KLocalizedString>
 #include <KConfigGroup>
 
 #include <QFile>
+#include <QApplication>
 
 #ifdef HAVE_YAZ
 extern "C" {
@@ -67,7 +67,7 @@ namespace {
 
   class YazCloser {
   public:
-    YazCloser(yaz_iconv_t iconv_) : iconv(iconv_), marc(0) {}
+    YazCloser(yaz_iconv_t iconv_) : iconv(iconv_), marc(nullptr) {}
     YazCloser(yaz_iconv_t iconv_, yaz_marc_t marc_) : iconv(iconv_), marc(marc_) {}
     ~YazCloser() {
       if(iconv) yaz_iconv_close(iconv);
@@ -94,8 +94,8 @@ Z3950ResultFound::~Z3950ResultFound() {
 
 class Z3950Connection::Private {
 public:
-  Private() {}
 #ifdef HAVE_YAZ
+  Private() : conn_opt(nullptr), conn(nullptr) {}
   ~Private() {
     ZOOM_options_destroy(conn_opt);
     ZOOM_connection_destroy(conn);
@@ -103,6 +103,8 @@ public:
 
   ZOOM_options conn_opt;
   ZOOM_connection conn;
+#else
+  Private() {}
 #endif
 };
 
@@ -137,7 +139,7 @@ Z3950Connection::Z3950Connection(Tellico::Fetch::Z3950Fetcher* fetcher,
 Z3950Connection::~Z3950Connection() {
   m_connected = false;
   delete d;
-  d = 0;
+  d = nullptr;
 }
 
 void Z3950Connection::reset() {
@@ -197,13 +199,13 @@ void Z3950Connection::run() {
     ZOOM_resultset_option_set(resultSet, "elementSetName", "mods");
     type = "xml";
   } else {
-    ZOOM_resultset_option_set(resultSet, "elementSetName", m_esn.toLatin1());
+    ZOOM_resultset_option_set(resultSet, "elementSetName", m_esn.toLatin1().constData());
   }
-  ZOOM_resultset_option_set(resultSet, "start", QByteArray::number(static_cast<int>(m_start)));
-  ZOOM_resultset_option_set(resultSet, "count", QByteArray::number(static_cast<int>(m_limit-m_start)));
+  ZOOM_resultset_option_set(resultSet, "start", QByteArray::number(static_cast<int>(m_start)).constData());
+  ZOOM_resultset_option_set(resultSet, "count", QByteArray::number(static_cast<int>(m_limit-m_start)).constData());
   // search in default syntax, unless syntax is already set
   if(!m_syntax.isEmpty()) {
-    ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", m_syntax.toLatin1());
+    ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", m_syntax.toLatin1().constData());
   }
 
   const char* errmsg;
@@ -237,7 +239,7 @@ void Z3950Connection::run() {
     int len;
     ZOOM_record rec = ZOOM_resultset_record(resultSet, 0);
     // want raw unless it's mods
-    ZOOM_record_get(rec, type, &len);
+    ZOOM_record_get(rec, type.constData(), &len);
     if(len > 0 && m_syntax.isEmpty()) {
       newSyntax = QString::fromLatin1(ZOOM_record_get(rec, "syntax", &len)).toLower();
       myLog() << "syntax guess is " << newSyntax;
@@ -259,36 +261,36 @@ void Z3950Connection::run() {
       myLog() << "changing z39.50 syntax to MODS";
       newSyntax = QLatin1String("xml");
       ZOOM_resultset_option_set(resultSet, "elementSetName", "mods");
-      ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", newSyntax.toLatin1());
+      ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", newSyntax.toLatin1().constData());
       rec = ZOOM_resultset_record(resultSet, 0);
       ZOOM_record_get(rec, "xml", &len);
       if(len == 0) {
         // change set name back
-        ZOOM_resultset_option_set(resultSet, "elementSetName", m_esn.toLatin1());
+        ZOOM_resultset_option_set(resultSet, "elementSetName", m_esn.toLatin1().constData());
         newSyntax = QLatin1String("usmarc"); // try usmarc
         myLog() << "changing z39.50 syntax to USMARC";
-        ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", newSyntax.toLatin1());
+        ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", newSyntax.toLatin1().constData());
         rec = ZOOM_resultset_record(resultSet, 0);
         ZOOM_record_get(rec, "raw", &len);
       }
       if(len == 0) {
         newSyntax = QLatin1String("marc21"); // try marc21
         myLog() << "changing z39.50 syntax to MARC21";
-        ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", newSyntax.toLatin1());
+        ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", newSyntax.toLatin1().constData());
         rec = ZOOM_resultset_record(resultSet, 0);
         ZOOM_record_get(rec, "raw", &len);
       }
       if(len == 0) {
         newSyntax = QLatin1String("unimarc"); // try unimarc
         myLog() << "changing z39.50 syntax to UNIMARC";
-        ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", newSyntax.toLatin1());
+        ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", newSyntax.toLatin1().constData());
         rec = ZOOM_resultset_record(resultSet, 0);
         ZOOM_record_get(rec, "raw", &len);
       }
       if(len == 0) {
         newSyntax = QLatin1String("grs-1"); // try grs-1
         myLog() << "changing z39.50 syntax to GRS-1";
-        ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", newSyntax.toLatin1());
+        ZOOM_resultset_option_set(resultSet, "preferredRecordSyntax", newSyntax.toLatin1().constData());
         rec = ZOOM_resultset_record(resultSet, 0);
         ZOOM_record_get(rec, "raw", &len);
       }
@@ -310,7 +312,7 @@ void Z3950Connection::run() {
   }
   // save syntax change for next time
   if(m_syntax != newSyntax) {
-    kapp->postEvent(m_fetcher.data(), new Z3950SyntaxChange(newSyntax));
+    qApp->postEvent(m_fetcher.data(), new Z3950SyntaxChange(newSyntax));
     m_syntax = newSyntax;
   }
 
@@ -394,7 +396,7 @@ bool Z3950Connection::makeConnection() {
   ZOOM_options_set(d->conn_opt, "password",           toCString(m_password));
 
   d->conn = ZOOM_connection_create(d->conn_opt);
-  ZOOM_connection_connect(d->conn, m_host.toLatin1(), m_port);
+  ZOOM_connection_connect(d->conn, m_host.toLatin1().constData(), m_port);
 
   int errcode;
   const char* errmsg; // unused: carries same info as 'errcode'
@@ -420,15 +422,15 @@ bool Z3950Connection::makeConnection() {
 
 void Z3950Connection::done() {
   checkPendingEvents();
-  kapp->postEvent(m_fetcher.data(), new Z3950ConnectionDone(m_hasMore));
+  qApp->postEvent(m_fetcher.data(), new Z3950ConnectionDone(m_hasMore));
 }
 
 void Z3950Connection::done(const QString& msg_, int type_) {
   checkPendingEvents();
   if(m_aborted) {
-    kapp->postEvent(m_fetcher.data(), new Z3950ConnectionDone(m_hasMore));
+    qApp->postEvent(m_fetcher.data(), new Z3950ConnectionDone(m_hasMore));
   } else {
-    kapp->postEvent(m_fetcher.data(), new Z3950ConnectionDone(m_hasMore, msg_, type_));
+    qApp->postEvent(m_fetcher.data(), new Z3950ConnectionDone(m_hasMore, msg_, type_));
   }
 }
 
@@ -440,8 +442,8 @@ void Z3950Connection::checkPendingEvents() {
 }
 
 inline
-QByteArray Z3950Connection::toCString(const QString& text_) {
-  return iconvRun(text_.toUtf8(), QLatin1String("utf-8"), m_sourceCharSet);
+const char* Z3950Connection::toCString(const QString& text_) {
+  return iconvRun(text_.toUtf8(), QLatin1String("utf-8"), m_sourceCharSet).constData();
 }
 
 inline
@@ -460,15 +462,15 @@ QByteArray Z3950Connection::iconvRun(const QByteArray& text_, const QString& fro
     return text_;
   }
 
-  yaz_iconv_t cd = yaz_iconv_open(toCharSet_.toLatin1(), fromCharSet_.toLatin1());
+  yaz_iconv_t cd = yaz_iconv_open(toCharSet_.toLatin1().constData(), fromCharSet_.toLatin1().constData());
   if(!cd) {
     // maybe it's iso 5426, which we sorta support
     QString charSetLower = fromCharSet_.toLower();
     charSetLower.remove(QLatin1Char('-')).remove(QLatin1Char(' '));
     if(charSetLower == QLatin1String("iso5426")) {
-      return iconvRun(Iso5426Converter::toUtf8(text_).toUtf8(), QLatin1String("utf-8"), toCharSet_);
+      return iconvRun(Iso5426Converter::toUtf8(text_).toUtf8().constData(), QLatin1String("utf-8"), toCharSet_);
     } else if(charSetLower == QLatin1String("iso6937")) {
-      return iconvRun(Iso6937Converter::toUtf8(text_).toUtf8(), QLatin1String("utf-8"), toCharSet_);
+      return iconvRun(Iso6937Converter::toUtf8(text_).toUtf8().constData(), QLatin1String("utf-8"), toCharSet_);
     }
     myWarning() << "conversion from" << fromCharSet_
                 << "to" << toCharSet_ << "is unsupported";
@@ -477,7 +479,7 @@ QByteArray Z3950Connection::iconvRun(const QByteArray& text_, const QString& fro
 
   YazCloser closer(cd);
 
-  const char* input = text_;
+  const char* input = text_.constData();
   size_t inlen = text_.length();
 
   size_t outlen = 2 * inlen;  // this is enough, right?
@@ -490,7 +492,7 @@ QByteArray Z3950Connection::iconvRun(const QByteArray& text_, const QString& fro
     return text_;
   }
   // bug in yaz, need to flush buffer to catch last character
-  yaz_iconv(cd, 0, 0, &result, &outlen);
+  yaz_iconv(cd, nullptr, nullptr, &result, &outlen);
 
   // length is pointer difference
   ptrdiff_t len = result - result0.data();
@@ -501,6 +503,8 @@ QByteArray Z3950Connection::iconvRun(const QByteArray& text_, const QString& fro
 //  myDebug() << "-------------------------------------------";
   return output;
 #endif
+  Q_UNUSED(fromCharSet_);
+  Q_UNUSED(toCharSet_);
   return text_;
 }
 
@@ -511,7 +515,7 @@ QString Z3950Connection::toXML(const QByteArray& marc_, const QString& charSet_)
     return QString();
   }
 
-  yaz_iconv_t cd = yaz_iconv_open("utf-8", charSet_.toLatin1());
+  yaz_iconv_t cd = yaz_iconv_open("utf-8", charSet_.toLatin1().constData());
   if(!cd) {
     // maybe it's iso 5426, which we sorta support
     QString charSetLower = charSet_.toLower();
@@ -548,20 +552,22 @@ QString Z3950Connection::toXML(const QByteArray& marc_, const QString& charSet_)
 #else
   const char* result;
 #endif
-  int r = yaz_marc_decode_buf(mt, marc_, -1, &result, &len);
+  int r = yaz_marc_decode_buf(mt, marc_.constData(), -1, &result, &len);
   if(r <= 0) {
     myDebug() << "can't decode buffer";
     return QString();
   }
 
   QString output = QLatin1String("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
-  output += QString::fromUtf8(QByteArray(result, len+1), len+1);
+  output += QString::fromUtf8(result, len+1);
 //  myDebug() << QCString(result);
 //  myDebug() << "-------------------------------------------";
 //  myDebug() << output;
 
   return output;
 #else // no yaz
+  Q_UNUSED(marc_);
+  Q_UNUSED(charSet_);
   return QString();
 #endif
 }
