@@ -29,12 +29,12 @@
 #include "entrygroup.h"
 #include "filter.h"
 #include "controller.h"
-#include "../tellico_debug.h"
 #include "models/entrygroupmodel.h"
 #include "models/groupsortmodel.h"
 #include "models/modelmanager.h"
 #include "models/models.h"
 #include "gui/countdelegate.h"
+#include "tellico_debug.h"
 
 #include <KLocalizedString>
 
@@ -54,17 +54,10 @@ GroupView::GroupView(QWidget* parent_)
   setHeaderHidden(false);
   setSelectionMode(QAbstractItemView::ExtendedSelection);
 
-  connect(this, SIGNAL(expanded(const QModelIndex&)),
-          SLOT(slotExpanded(const QModelIndex&)));
-
-  connect(this, SIGNAL(collapsed(const QModelIndex&)),
-          SLOT(slotCollapsed(const QModelIndex&)));
-
-  connect(this, SIGNAL(doubleClicked(const QModelIndex&)),
-          SLOT(slotDoubleClicked(const QModelIndex&)));
-
-  connect(header(), SIGNAL(sortIndicatorChanged(int,Qt::SortOrder)),
-          SLOT(slotSortingChanged(int,Qt::SortOrder)));
+  connect(this, &GroupView::expanded, this, &GroupView::slotExpanded);
+  connect(this, &GroupView::collapsed, this, &GroupView::slotCollapsed);
+  connect(this, &GroupView::doubleClicked, this, &GroupView::slotDoubleClicked);
+  connect(header(), &QHeaderView::sortIndicatorChanged, this, &GroupView::slotSortingChanged);
 
   m_groupOpenIconName = QLatin1String("folder-open");
   m_groupClosedIconName = QLatin1String("folder");
@@ -97,8 +90,8 @@ void GroupView::addCollection(Tellico::Data::CollPtr coll_) {
   // when the coll gets set for the first time, the pixmaps need to be updated
   if((m_coll->hasField(m_groupBy) && m_coll->fieldByName(m_groupBy)->formatType() == FieldFormat::FormatName)
      || m_groupBy == Data::Collection::s_peopleGroupName) {
-    m_groupOpenIconName = QLatin1String("person-open");
-    m_groupClosedIconName = QLatin1String("person");
+    m_groupOpenIconName = QLatin1String(":/icons/person-open");
+    m_groupClosedIconName = QLatin1String(":/icons/person");
   }
 
   updateHeader();
@@ -179,7 +172,7 @@ void GroupView::setEntrySelected(Tellico::Data::EntryPtr entry_) {
     return;
   }
 
-  Data::EntryGroup* group = 0;
+  Data::EntryGroup* group = nullptr;
   foreach(Data::EntryGroup* tmpGroup, entry_->groups()) {
     if(tmpGroup->fieldName() == m_groupBy) {
       group = tmpGroup;
@@ -301,8 +294,8 @@ void GroupView::setGroupField(const QString& groupField_) {
   }
   if((m_coll->hasField(groupField_) && m_coll->fieldByName(groupField_)->formatType() == Tellico::FieldFormat::FormatName)
      || groupField_ == Tellico::Data::Collection::s_peopleGroupName) {
-    m_groupOpenIconName = QLatin1String("person-open");
-    m_groupClosedIconName = QLatin1String("person");
+    m_groupOpenIconName = QLatin1String(":/icons/person-open");
+    m_groupClosedIconName = QLatin1String(":/icons/person");
   } else {
     m_groupOpenIconName = QLatin1String("folder-open");
     m_groupClosedIconName = QLatin1String("folder");
@@ -339,8 +332,12 @@ void GroupView::slotFilterGroup() {
       }
     } else {
       Data::EntryGroup* group = model()->data(index, GroupPtrRole).value<Data::EntryGroup*>();
-      if(group && !group->hasEmptyGroupName()) {
-        filter->append(new FilterRule(m_groupBy, group->groupName(), FilterRule::FuncContains));
+      if(group) {
+        if(group->hasEmptyGroupName()) {
+          filter->append(new FilterRule(m_groupBy, QString(), FilterRule::FuncEquals));
+        } else {
+          filter->append(new FilterRule(m_groupBy, group->groupName(), FilterRule::FuncContains));
+        }
       }
     }
   }
@@ -408,4 +405,3 @@ void GroupView::addGroup(Tellico::Data::EntryGroup* group_) {
     sourceModel()->setData(index, m_groupClosedIconName, Qt::DecorationRole);
   }
 }
-
