@@ -28,8 +28,6 @@
 #include "gui/treeview.h"
 #include "observer.h"
 
-#include <QPixmap>
-
 namespace Tellico {
   namespace Data {
     class EntryGroup;
@@ -103,9 +101,9 @@ public:
    */
   void setEntrySelected(Data::EntryPtr entry);
 
-  virtual void modifyField(Data::CollPtr coll, Data::FieldPtr oldField, Data::FieldPtr newField);
+  virtual void modifyField(Data::CollPtr coll, Data::FieldPtr oldField, Data::FieldPtr newField) Q_DECL_OVERRIDE;
 
-public slots:
+public Q_SLOTS:
   /**
    * Resets the list view, clearing and deleting all items.
    */
@@ -119,7 +117,7 @@ public slots:
   void slotModifyGroups(Tellico::Data::CollPtr coll, QList<Tellico::Data::EntryGroup*> groups);
 
 private:
-  void contextMenuEvent(QContextMenuEvent* event);
+  void contextMenuEvent(QContextMenuEvent* event) Q_DECL_OVERRIDE;
   /**
    * Inserts a listviewitem for a given group
    *
@@ -131,7 +129,7 @@ private:
   QString groupTitle();
   void updateHeader(Data::FieldPtr field=Data::FieldPtr());
 
-private slots:
+private Q_SLOTS:
   /**
    * Handles changing the icon when an item is expanded, depended on whether it refers
    * to a collection, a group, or an entry.
@@ -146,11 +144,10 @@ private slots:
    * Filter by group
    */
   void slotFilterGroup();
-  void selectionChanged(const QItemSelection& selected, const QItemSelection& deselected);
   void slotDoubleClicked(const QModelIndex& index);
   void slotSortingChanged(int column, Qt::SortOrder order);
 
-signals:
+Q_SIGNALS:
   /**
    * Signals a desire to filter the view.
    *
