@@ -24,15 +24,15 @@
 
 #include "imagedirectory.h"
 #include "image.h"
-#include "filehandler.h"
+#include "../core/filehandler.h"
 #include "../tellico_debug.h"
 
-#include <kurl.h>
-#include <ktempdir.h>
-#include <kzip.h>
+#include <KZip>
 
 #include <QFile>
 #include <QDir>
+#include <QUrl>
+#include <QTemporaryDir>
 
 using namespace Tellico;
 using Tellico::ImageStorage;
@@ -40,25 +40,26 @@ using Tellico::ImageDirectory;
 using Tellico::TemporaryImageDirectory;
 using Tellico::ImageZipArchive;
 
-ImageDirectory::ImageDirectory() : ImageStorage(), m_pathExists(false), m_dir(0) {
+ImageDirectory::ImageDirectory() : ImageStorage(), m_pathExists(false), m_dir(nullptr) {
 }
 
-ImageDirectory::ImageDirectory(const QString& path_) : ImageStorage() , m_dir(0) {
+ImageDirectory::ImageDirectory(const QString& path_) : ImageStorage() , m_dir(nullptr) {
   setPath(path_);
 }
 
 ImageDirectory::~ImageDirectory() {
   delete m_dir;
-  m_dir = 0;
+  m_dir = nullptr;
 }
 
 QString ImageDirectory::path() {
   if(m_path.isEmpty()) {
     // an empty path means the file hasn't been saved yet
     if(!m_dir) {
-      m_dir = new KTempDir(); // default is to auto-delete, aka autoRemove()
+      m_dir = new QTemporaryDir(); // default is to auto-delete, aka autoRemove()
     }
-    setPath(m_dir->name());
+    // in KDE4, the way this worked included the final slash.
+    setPath(m_dir->path() + QLatin1Char('/'));
   }
   return m_path;
 }
@@ -75,20 +76,18 @@ bool ImageDirectory::hasImage(const QString& id_) {
 
 Tellico::Data::Image* ImageDirectory::imageById(const QString& id_) {
   if(!hasImage(id_)) {
-    return 0;
+    return nullptr;
   }
 
-  KUrl imgUrl;
-  imgUrl.setPath(path() + id_);
-  Data::Image* img = FileHandler::readImageFile(imgUrl, id_, true /* quiet */);
+  Data::Image* img = new Data::Image(path() + id_, id_);
   if(!img) {
-    myLog() << "image not found:" << imgUrl;
-    return 0;
+    myLog() << "image not found:" << (path() + id_);
+    return nullptr;
   }
   if(img->isNull()) {
-    myLog() << "image found but null:" << imgUrl;
+    myLog() << "image found but null:" << (path() + id_);
     delete img;
-    return 0;
+    return nullptr;
   }
   return img;
 }
@@ -99,22 +98,21 @@ bool ImageDirectory::writeImage(const Data::Image& img_) {
     if(path.isEmpty()) {
       // an empty path means the file hasn't been saved yet
       if(!m_dir) {
-        m_dir = new KTempDir(); // default is to auto-delete, aka autoRemove()
-        ImageDirectory::setPath(m_dir->name());
+        m_dir = new QTemporaryDir(); // default is to auto-delete, aka autoRemove()
+        ImageDirectory::setPath(m_dir->path());
       }
       return writeImage(img_);
     }
     QDir dir(path);
     if(dir.mkdir(path)) {
-      myLog() << "created" << path;
+//      myLog() << "created" << path;
     } else {
       myWarning() << "unable to create dir:" << path;
     }
     m_pathExists = true;
   }
-  KUrl target;
-  target.setPath(path);
-  target.setFileName(img_.id());
+  QUrl target = QUrl::fromLocalFile(path);
+  target.setPath(target.path() + img_.id());
   return FileHandler::writeDataURL(target, img_.byteArray(), true /* force */);
 }
 
@@ -122,7 +120,7 @@ bool ImageDirectory::removeImage(const QString& id_) {
   return QFile::remove(path() + id_);
 }
 
-TemporaryImageDirectory::TemporaryImageDirectory() : ImageDirectory(), m_dir(0) {
+TemporaryImageDirectory::TemporaryImageDirectory() : ImageDirectory(), m_dir(nullptr) {
 }
 
 TemporaryImageDirectory::~TemporaryImageDirectory() {
@@ -131,13 +129,14 @@ TemporaryImageDirectory::~TemporaryImageDirectory() {
 
 void TemporaryImageDirectory::purge() {
   delete m_dir;
-  m_dir = 0;
+  m_dir = nullptr;
 }
 
 QString TemporaryImageDirectory::path() {
   if(!m_dir) {
-    m_dir = new KTempDir(); // default is to auto-delete, aka autoRemove()
-    ImageDirectory::setPath(m_dir->name());
+    m_dir = new QTemporaryDir(); // default is to auto-delete, aka autoRemove()
+    // in KDE4, the way this worked included the final slash.
+    ImageDirectory::setPath(m_dir->path() + QLatin1Char('/'));
   }
   return ImageDirectory::path();
 }
@@ -147,30 +146,30 @@ void TemporaryImageDirectory::setPath(const QString& path) {
   Q_ASSERT(path.isEmpty()); // should never be called, that's why it's private
 }
 
-ImageZipArchive::ImageZipArchive() : ImageStorage(), m_zip(0) {
+ImageZipArchive::ImageZipArchive() : ImageStorage(), m_zip(nullptr), m_imgDir(nullptr) {
 }
 
 ImageZipArchive::~ImageZipArchive() {
   delete m_zip;
-  m_zip = 0;
+  m_zip = nullptr;
 }
 
 void ImageZipArchive::setZip(KZip* zip_) {
   m_images.clear();
   delete m_zip;
   m_zip = zip_;
-  m_imgDir = 0;
+  m_imgDir = nullptr;
 
   const KArchiveDirectory* dir = m_zip->directory();
   if(!dir) {
     delete m_zip;
-    m_zip = 0;
+    m_zip = nullptr;
     return;
   }
   const KArchiveEntry* imgDirEntry = dir->entry(QLatin1String("images"));
   if(!imgDirEntry || !imgDirEntry->isDirectory()) {
     delete m_zip;
-    m_zip = 0;
+    m_zip = nullptr;
     return;
   }
   m_imgDir = static_cast<const KArchiveDirectory*>(imgDirEntry);
@@ -183,9 +182,9 @@ bool ImageZipArchive::hasImage(const QString& id_) {
 
 Tellico::Data::Image* ImageZipArchive::imageById(const QString& id_) {
   if(!hasImage(id_)) {
-    return 0;
+    return nullptr;
   }
-  Data::Image* img = 0;
+  Data::Image* img = nullptr;
   const KArchiveEntry* file = m_imgDir->entry(id_);
   if(file && file->isFile()) {
     img = new Data::Image(static_cast<const KArchiveFile*>(file)->data(),
@@ -196,17 +195,17 @@ Tellico::Data::Image* ImageZipArchive::imageById(const QString& id_) {
   m_images.remove(id_);
   if(m_images.isEmpty()) {
     delete m_zip;
-    m_zip = 0;
-    m_imgDir = 0;
+    m_zip = nullptr;
+    m_imgDir = nullptr;
   }
   if(!img) {
     myLog() << "image not found:" << id_;
-    return 0;
+    return nullptr;
   }
   if(img->isNull()) {
     myLog() << "image found but null:" << id_;
     delete img;
-    return 0;
+    return nullptr;
   }
   return img;
 }
