@@ -46,7 +46,8 @@ void OMDBFetcherTest::initTestCase() {
 }
 
 void OMDBFetcherTest::testTitle() {
-  KConfig config(QFINDTESTDATA("tellicotest.config"), KConfig::SimpleConfig);
+  // all the private API test config is in amazonfetchertest.config right now
+  KConfig config(QFINDTESTDATA("amazonfetchertest.config"), KConfig::SimpleConfig);
   QString groupName = QLatin1String("OMDB");
   if(!config.hasGroup(groupName)) {
     QSKIP("This test requires a config file.", SkipAll);
@@ -77,15 +78,25 @@ void OMDBFetcherTest::testTitle() {
   QVERIFY(!castList.isEmpty());
   QCOMPARE(castList.at(0), QLatin1String("Brandon Routh"));
   QVERIFY(!entry->field(QLatin1String("cover")).isEmpty());
+  QVERIFY(!entry->field(QLatin1String("cover")).contains(QLatin1Char('/')));
   QVERIFY(!entry->field(QLatin1String("plot")).isEmpty());
   QCOMPARE(entry->field(QLatin1String("imdb")), QLatin1String("http://www.imdb.com/title/tt0348150/"));
 }
 
 // see https://bugs.kde.org/show_bug.cgi?id=336765
 void OMDBFetcherTest::testBabel() {
+  // all the private API test config is in amazonfetchertest.config right now
+  KConfig config(QFINDTESTDATA("amazonfetchertest.config"), KConfig::SimpleConfig);
+  QString groupName = QLatin1String("OMDB");
+  if(!config.hasGroup(groupName)) {
+    QSKIP("This test requires a config file.", SkipAll);
+  }
+  KConfigGroup cg(&config, groupName);
+
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Video, Tellico::Fetch::Title,
                                        QLatin1String("babel"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::OMDBFetcher(this));
+  fetcher->readConfig(cg, cg.name());
 
   Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
 
@@ -94,5 +105,5 @@ void OMDBFetcherTest::testBabel() {
   Tellico::Data::EntryPtr entry = results.at(0);
   QCOMPARE(entry->field("title"), QLatin1String("Babel"));
   QCOMPARE(entry->field("year"), QLatin1String("2006"));
-  QCOMPARE(entry->field("director"), QString::fromUtf8("Alejandro G. Iñárritu"));
+  QCOMPARE(entry->field("director"), QString::fromUtf8("Alejandro González Iñárritu"));
 }
