@@ -40,8 +40,8 @@ public:
   AMCImporter(const QUrl& url);
   virtual ~AMCImporter();
 
-  virtual Data::CollPtr collection();
-  bool canImport(int type) const;
+  virtual Data::CollPtr collection() Q_DECL_OVERRIDE;
+  bool canImport(int type) const Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
   void slotCancel();
