@@ -47,11 +47,11 @@ public:
 
   /**
    */
-  virtual Data::CollPtr collection();
+  virtual Data::CollPtr collection() Q_DECL_OVERRIDE;
   /**
    */
-  virtual QWidget* widget(QWidget*) { return 0; }
-  virtual bool canImport(int type) const;
+  virtual QWidget* widget(QWidget*) Q_DECL_OVERRIDE { return nullptr; }
+  virtual bool canImport(int type) const Q_DECL_OVERRIDE;
 
   void setHasRelativeImageLinks(bool b) { m_relativeImageLinks = b; }
 
