@@ -25,7 +25,7 @@
 #include "goodreadsimporter.h"
 #include "xslthandler.h"
 #include "tellicoimporter.h"
-#include "filehandler.h"
+#include "../core/filehandler.h"
 #include "../utils/datafileregistry.h"
 #include "../tellico_debug.h"
 
@@ -49,7 +49,7 @@ namespace {
 
 using Tellico::Import::GoodreadsImporter;
 
-GoodreadsImporter::GoodreadsImporter() : Import::Importer(), m_widget(0), m_userEdit(0) {
+GoodreadsImporter::GoodreadsImporter() : Import::Importer(), m_widget(nullptr), m_userEdit(nullptr) {
   QString xsltFile = DataFileRegistry::self()->locate(QLatin1String("goodreads2tellico.xsl"));
   if(!xsltFile.isEmpty()) {
     m_xsltURL = QUrl::fromLocalFile(xsltFile);
